<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Welcome screen (dashboard) after user authentication
*                  Modify the dashboard to display relevant information about your 
*                  infrastructure. This page is also be used as a pre-loader for 
*                  template, datacenter and device sessions. Ensure that all sessions 
*                  are generated on page load and that no session reload occurs unless 
*                  data is changed. Avoid adding forms to this page as its purpose is 
*                  to display data.
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

$err_msg = "";

// let's collect some info on our infrastructure

$arr_devices = [];
$arr_devices_key = [];

if (!isset($_SESSION['devices_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
    $arr_devices_list = json_decode($devices_list_return, true);
    if(count($arr_devices_list) > 0){
        $_SESSION['devices_list'] = $arr_devices_list;
        $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}

$i = 0;
foreach ($_SESSION['devices_list']['item_list'] as $device_data){
    $myarr = $utilities_library->mk_array($device_data['key'],$device_data['property_list']);
    $arr_devices[$i] = $myarr;
    $arr_devices_key[$device_data['key']] = $myarr;
    $i++;
}

# additional sessions we need on this page:
# templates
$arr_templates = [];
$arr_templates_key = [];
if (!isset($_SESSION['templates_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
    $arr_devices_list = json_decode($devices_list_return, true);
    if(count($arr_devices_list) > 0){
        $_SESSION['templates_list'] = $arr_devices_list;
        $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}
$j = 0;
foreach ($_SESSION['templates_list']['item_list'] as $template_data){
    $myarr = $utilities_library->mk_array($template_data['key'],$template_data['property_list']);
    $arr_templates[$j] = $myarr;
    $arr_templates_key[$template_data['key']] = $myarr;
    $j++;
}

# datacenters:
$arr_datacenters = [];
$arr_datacenters_key = [];
if (!isset($_SESSION['datacenters_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
    $arr_datacenters_list = json_decode($datacenters_list_return, true);
    if(count($arr_datacenters_list) > 0){
        $_SESSION['datacenters_list'] = $arr_datacenters_list;
        $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}
$k = 0;
foreach ($_SESSION['datacenters_list']['item_list'] as $datacenter_data){
    $myarr = $utilities_library->mk_array($datacenter_data['key'],$datacenter_data['property_list']);
    $arr_datacenters[$k] = $myarr;
    $arr_datacenters_key[$datacenter_data['key']] = $myarr;
    $k++;
}

require_once(WEB_ROOT.'/incl/top.php');

?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">

    <h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_dashboard', DEFAULT_LANG); ?></h2>

    <!-- 
    <div class="pb_container">
        <div class="progress progress-striped success">
          <div class="progress-bar" role="progressbar" aria-valuemin="0" aria-valuemax="100" style="width: 0%"></div>
        </div>
    </div>
    -->
    

        <div class="row">
            <div class="col-md-4">
                <h3><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_templates_head', DEFAULT_LANG); ?></h3>
                <p><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_templates_intro', DEFAULT_LANG); ?></p>
                <p><a class="btn btn-primary" href="mgtemplates.php" role="button"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_templates_btn_manage', DEFAULT_LANG); ?> &raquo;</a></p>
            </div>
            <div class="col-md-4">
                <h3><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_devices_mg_head', DEFAULT_LANG); ?></h3>
                <p><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_devices_mg_intro', DEFAULT_LANG); ?></p>
                <p><a class="btn btn-warning" href="mgdevices.php" role="button"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_devices_mg_btn', DEFAULT_LANG); ?> &raquo;</a></p>
            </div>
        </div>

<?php
if (isset($arr_devices_key) && $arr_devices_key != null && count($arr_devices_key) > 0 ){
?>
        <div class="row">
            <div class="col-md-8">
                <h3><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_dashboard_head', DEFAULT_LANG); ?></h3>
                <p><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_dashboard_intro', DEFAULT_LANG); ?></p>
            </div>
            <div class="col-md-8">
            <?php 
            print "<table class=\"table table-condensed\">";
            
            $dc_act = 0;
            $dc_inact = 0;
            $dc_all = count($arr_datacenters_key);
            foreach ($arr_datacenters_key as $dc_info){
                if($dc_info['active_yn'] == 'True'){
                    $dc_act++;
                }
                if($dc_info['active_yn'] == 'False'){
                    $dc_inact++;
                }
            }
            $dc_act_perc = round($dc_act*100/$dc_all,2);
            $dc_inact_perc = round($dc_inact*100/$dc_all,2);
                print "<tr>";
                print "<td><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_pghead_datacenters', DEFAULT_LANG)."</b></td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_active', DEFAULT_LANG).": ".$dc_act." (".$dc_act_perc."%)</td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_inactive', DEFAULT_LANG).": ".$dc_inact." (".$dc_inact_perc."%)</td>";
                print "</tr>";
            
                foreach ($arr_templates_key as $tp_data){
                    if($tp_data['active_yn'] == 'True'){
                        $dev_stats = $utilities_library->simple_arr_cnt_by_filter($arr_devices_key,'template_id',$tp_data['key']);
                        
                        print "<tr>";
                        print "<td><b>".$tp_data['template_name'].":</b></td>";
                        print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_active', DEFAULT_LANG).": ".$dev_stats['active_cnt']." (".$dev_stats['active_perc']."%)</td>";
                        print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_inactive', DEFAULT_LANG).": ".$dev_stats['inactive_cnt']." (".$dev_stats['inactive_perc']."%)</td>";
                        print "</tr>";
                    }
                }
            print "</table>";
            
            print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_pghead_datacenters', DEFAULT_LANG).":</h4>";
            print "<table class=\"table table-condensed\">";
            foreach ($arr_datacenters_key as $dc_data){
                $tr_class = "info";
                $datacenter_name = 'N/A';
                $racks_count = 0;
                $iconn_count = 0;
                $bandwidth = 'N/A';
                $power = 'N/A';
                if(isset($dc_data['datacenter_name']) && $dc_data['datacenter_name'] != null && $dc_data['datacenter_name'] != ''){
                    $datacenter_name = $dc_data['datacenter_name'];
                }   
                if(isset($dc_data['racks_count']) && $dc_data['racks_count'] != null && $dc_data['racks_count'] != ''){
                    $racks_count = $dc_data['racks_count'];
                } 
                if(isset($dc_data['iconn_count']) && $dc_data['iconn_count'] != null && $dc_data['iconn_count'] != ''){
                    $iconn_count = $dc_data['iconn_count'];
                }
                if(isset($dc_data['bandwidth']) && $dc_data['bandwidth'] != null && $dc_data['bandwidth'] != ''){
                    $bandwidth = $dc_data['bandwidth'];
                }
                if(isset($dc_data['dc_power']) && $dc_data['dc_power'] != null && $dc_data['dc_power'] != ''){
                    $power = $dc_data['dc_power'];
                }
                if($dc_data['active_yn'] == 'True'){
                    $tr_class = "success";
                }else{
                    $tr_class = "danger";
                }
                print "<tr class=\"".$tr_class."\">";
                print "<td><b>".$dc_data['datacenter_name']."</b></td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_racks', DEFAULT_LANG).": ".$racks_count."</td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_interconnect', DEFAULT_LANG).": ".$iconn_count."</td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_bandwidth', DEFAULT_LANG).": ".$bandwidth."</td>";
                print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_power', DEFAULT_LANG).": ".$power."</td>";
                print "</tr>";
                foreach ($arr_templates_key as $tp_data){
                    if($tp_data['active_yn'] == 'True'){
                        $dev_stats = $utilities_library->arr_cnt_by_filter($arr_devices_key,'template_id',$tp_data['key'],'datacenter_id',$dc_data['key']);
                        print "<tr class=\"".$tr_class."\">";
                        print "<td>&nbsp;</td>";
                        print "<td>&nbsp;</td>";
                        print "<td><b>".$tp_data['template_name'].":</b></td>";
                        print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_active', DEFAULT_LANG).": ".$dev_stats['active_cnt']." (".$dev_stats['active_perc']."%)</td>";
                        print "<td>".$formatting_library->make_lang_label($arr_labels, 'lbl_inactive', DEFAULT_LANG).": ".$dev_stats['inactive_cnt']." (".$dev_stats['inactive_perc']."%)</td>";
                        print "</tr>";
                    }
                }
                print "<tr><td colspan=\"5\">&nbsp;</td></tr>";
            }
            
            print "</table>";
            ?>

            </div>
        </div>

<?php
}else{
?>
        <div class="row">
            <div class="col-md-8">
                <h3><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_dashboard_head', DEFAULT_LANG); ?></h3>
                <p><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_dashboard_intro_nodev', DEFAULT_LANG); ?></p>
            </div>
        </div>
<?php
}

require_once(WEB_ROOT.'/incl/bottom.php');

?>
