<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Datacenters management page
*                  This page is a full-feature module that allows editing, 
*                  viewing and addition of datacenters. Form field components 
*                  are driven from the lib/form_fields.php file, 
*                  $arr_dc_data_format array. It is mandatory that you pre-define 
*                  form fields in $arr_dc_data_format and add necessary labels in 
*                  all used language files before applying changes to this module. 
*                  After each change or addition to the data centers list, the 
*                  datacenters_list and datacenters_list_create_dt sessions must 
*                  be refreshed.
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

$err_msg = "";

// create datacenters session if not already created
if (!isset($_SESSION['datacenters_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
    $arr_datacenters_list = json_decode($datacenters_list_return, true);
    if(count($arr_datacenters_list) > 0){
        $_SESSION['datacenters_list'] = $arr_datacenters_list;
        $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}

// set array of datacenters
$arr_dc = [];
$arr_dc_key = [];
$i = 0;
foreach ($_SESSION['datacenters_list']['item_list'] as $dc_data){
    $myarr = $utilities_library->mk_array($dc_data['key'],$dc_data['property_list']);
    $arr_dc[$i] = $myarr;
    $arr_dc_key[$dc_data['key']] = $myarr;
    $i++;
}

// define page number variable
$pg_num = 0;
if (isset($_GET['pg']) && $_GET['pg'] > 0){
    $pg_num = $_GET['pg'];
}

// define page action variable
$action = "";
if (isset($_GET['do']) && ($_GET['do'] == 'json_download' || $_GET['do'] == 'xml_download' || $_GET['do'] == 'json' || $_GET['do'] == 'json_map' || $_GET['do'] == 'file_delete' || $_GET['do'] == 'add' || $_GET['do'] == 'edit_dc' || $_GET['do'] == 'save' || $_GET['do'] == 'activate' || $_GET['do'] == 'deactivate' || $_GET['do'] == 'add_success' || $_GET['do'] == 'deactivate_success' || $_GET['do'] == 'activate_success' || $_GET['do'] == 'save_success')){
    $action = $_GET['do'];
}

// define dc_id variable
$dc_id = '';
if (isset($_GET['dc_id']) && str_replace(' ','',$_GET['dc_id']) != ''){
    $dc_id = $_GET['dc_id'];
}

// show datacenters list as json for search
if($action == 'json'){
    $arr_json = [];
    $i = 0;
    foreach ($_SESSION['datacenters_list']['item_list']  as $dc_data){
        $arr_dc = $utilities_library->mk_array($dc_data['key'],$dc_data['property_list']);
        $arr_d = ['id' => $dc_data['key'], 'name'=>"".$arr_dc['datacenter_name']." ".$arr_dc['datacenter_code']." [".$arr_dc['datacenter_address']."]"];
        $arr_json[$i] = $arr_d;
        $i = $i + 1;
    }
    header('Cache-Control: no-cache, must-revalidate');
    header('Content-type: application/json');
    print json_encode($arr_json,true);
    exit;
}

if($action == 'json_download' || $action == 'xml_download'){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
    $arr_datacenters_list = json_decode($datacenters_list_return, true);
    if(count($arr_datacenters_list) > 0){
        $_SESSION['datacenters_list'] = $arr_datacenters_list;
        $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
    $arr_json = [];
    foreach ($_SESSION['datacenters_list']['item_list']  as $dc_data){
        $arr_dc = $utilities_library->mk_array($dc_data['key'],$dc_data['property_list']);
        $arr_json[$dc_data['key']] = $arr_dc;
    }
    header('Cache-Control: no-cache, must-revalidate');
    
    if($action == 'json_download'){
        header("Content-Disposition: attachment; filename=datacenter.json");
        header('Content-type: application/json');
        print json_encode($arr_json,true);
        exit;
    }else if($action == 'xml_download'){
        $xml1 = xmlrpc_encode($arr_json);
        header("Content-Disposition: attachment; filename=datacenter.xml");
        header('Content-type: application/json');
        echo $xml1;
        exit;
    }
}

if($action == 'json_map'){
    $arr_json = [];
    $i = 0;
    foreach ($_SESSION['datacenters_list']['item_list']  as $dc_data){
        $arr_dc = $utilities_library->mk_array($dc_data['key'],$dc_data['property_list']);
        if(strtolower($arr_dc['active_yn']) == 'true'){
            $arr_d = [
                'id' => $dc_data['key'], 
                'datacenter_name' => $arr_dc['datacenter_name'], 
                'datacenter_code' => $arr_dc['datacenter_code'], 
                'datacenter_address' => $arr_dc['datacenter_address'],
                'datacenter_lat' => $arr_dc['datacenter_lat'],
                'datacenter_long' => $arr_dc['datacenter_long'],
                'modified_on' => $arr_dc['modified_on']
            ];
            $arr_json[$i] = $arr_d;
            $i = $i + 1;
        }
    }
    header('Cache-Control: no-cache, must-revalidate');
    header('Content-type: application/json');
    print json_encode($arr_json,true);
    exit;
}

if($action == 'file_delete'){
    $file_id = [
    'file_id' => $_GET['file_id']
    ];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $file_return = $rest_client->delete(WEB_SERVICE_ADDRESS.'/files',json_encode($file_id,true));
    $file_return = json_decode($file_return, true);
    if ((str_replace(' ','',$file_return['message']) != '' && $file_return['status'] > 300 && $file_return['status'] < 600) || (str_replace(' ','',$file_return['message']) != '' && $file_return['status'] > 300 && $file_return['status'] < 600)) {
        print $file_return['message'];
    }else{
        header("location: ".CURRENT_PAGE."?dc_id=".$dc_id."&pg=".$pg_num."&do=edit_dc&at=doc");
    }
}

if($action == 'deactivate' || $action == 'activate'){
    // do we have a dc_id?
    if($dc_id != ''){
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        
        $arr_new_dc_data = $arr_dc_key[$dc_id];
        // fix for unconverted data remains: .000000 error
        // when ms are added in a date/time string
        $arr_new_dc_data['created_on'] = explode('.',$arr_new_dc_data['created_on'])[0];
        $arr_new_dc_data['modified_on'] = explode('.',$arr_new_dc_data['modified_on'])[0];
        if($action == 'activate'){
            $arr_new_dc_data['active_yn'] = 'True';
        }else{
            $arr_new_dc_data['active_yn'] = 'False';
        }
        $post_dc_data = $utilities_library->mk_json_props_array($dc_id,$arr_new_dc_data,$arr_new_dc_data);
        
        // submit to app server
        $dc_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($post_dc_data,true));
        $arr_dc_return = json_decode($dc_return,true);
        // check for final errors
        if ((str_replace(' ','',$arr_dc_return['message']) != '' && $arr_dc_return['status'] > 300 && $arr_dc_return['status'] < 600) || (str_replace(' ','',$arr_dc_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
            $err_message = $arr_dc_return['message'];
        }else{
            // no errors; we re-generate the users list session and
            // redirect to nice success page
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $dc_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
            $arr_dc_list = json_decode($dc_list_return, true);
            if(count($arr_dc_list) > 0){
                $_SESSION['datacenters_list'] = $arr_dc_list;
                $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }
                
            if($_GET['do'] == 'activate'){
                header("location: ".CURRENT_PAGE."?do=activate_success&pg=".$pg_num."&dc_id=".$dc_id."");
            }else{
                header("location: ".CURRENT_PAGE."?do=deactivate_success&pg=".$pg_num."&dc_id=".$dc_id."");
            }
        }
    }
}

if($action == 'add'){
    $err_message = "";
    
    /*
    // make array from $_POST and format the racks section
    $arr_rack_type = $_POST['rack_type'];
    $arr_rack_row = $_POST['rack_row'];
    $arr_rack_num = $_POST['rack_num'];
    $arr_rack_label = $_POST['rack_label'];
    $arr_rack_size = $_POST['rack_size'];
    $i = 1;
    $j = 0;
    
    foreach ($arr_rack_type as $rack_detail) {
        if(isset($rack_detail) && $rack_detail != ''){
            $_POST['rack_type_'.$i.''] = $rack_detail;
            $_POST['rack_row_'.$i.''] = $arr_rack_row[$j];
            $_POST['rack_num_'.$i.''] = $arr_rack_num[$j];
            $_POST['rack_label_'.$i.''] = $arr_rack_label[$j];
            $_POST['rack_size_'.$i.''] = $arr_rack_size[$j];
            $i++;
        }
        $j++;
    }
    $_POST['racks_count'] = $i-1;
    
    
    unset($_POST['rack_type']);
    unset($_POST['rack_row']);
    unset($_POST['rack_num']);
    unset($_POST['rack_label']);
    unset($_POST['rack_size']);
    */
    
    // form field validation
    $form_validation = $utilities_library->form_fields_validation($arr_dc_data_format,$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        // avoid EOL while scanning string literal errors
        foreach ($arr_dc_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }
        
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $post_dc_data = $utilities_library->mk_json_props_array('',$_POST,$_POST);

        $dc_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($post_dc_data,true));
        $arr_dc_return = json_decode($dc_return,true);
        // check for final errors
        if (str_replace(' ','',$arr_dc_return['message']) != '' && $arr_dc_return['status'] > 300 && $arr_dc_return['status'] < 600) {
            $err_message .= $arr_dc_return['message'];
        }else{
            $new_dc_info = $utilities_library->mk_array($arr_dc_return['key'],$arr_dc_return['property_list']);
            # add files
            # identify file fields
            foreach ($arr_dc_data_format as $fields_format){
                # for each group, list fields
                foreach ($fields_format as $fields_data){
                    if($fields_data['field_type'] == 'file'){
                        $arr_file_data = $_FILES[$fields_data['field_name']];
                        if($arr_file_data['size'] > 0){
                            // we have a file
                            // let's organize data
                            $det_str = $fields_data['field_name']."_details";
                            $arr_new_file_data['file_id'] = '';
                            $arr_new_file_data['created_by'] = $_SESSION['user_data']['key'];
                            $arr_new_file_data['created_on'] = '';
                            $arr_new_file_data['modified_by'] = $_SESSION['user_data']['key'];
                            $arr_new_file_data['modified_on'] = '';
                            $arr_new_file_data['class_id'] = $new_dc_info['key'];
                            $arr_new_file_data['file_type'] = $arr_file_data['type'];
                            $arr_new_file_data['file_size'] = $arr_file_data['size'];
                            $arr_new_file_data['company_id'] = $_SESSION['auth_head']['auth_head_company_id'];
                            $arr_new_file_data['file_data'] = base64_encode(file_get_contents($arr_file_data['tmp_name']));
                            $arr_new_file_data['file_description'] = $_POST[$det_str];
                            $arr_new_file_data['file_item'] = $fields_data['field_name'];
                            $arr_new_file_data['file_checksum'] = '';
                            $arr_new_file_data['file_name'] = $arr_file_data['name'];
                            $arr_new_file_data['file_class'] = 'DATACENTER';
                            
                            // make json array
                            $post_file_data = $utilities_library->mk_json_props_array('',$arr_new_file_data,$arr_new_file_data);
                            // upload data
                            $file_upload = $rest_client->put(WEB_SERVICE_ADDRESS.'/files',json_encode($post_file_data,true));
                            $arr_file_upload = json_decode($file_upload,true);
                                
                            // check for final errors
                            if (str_replace(' ','',$arr_file_upload['message']) != '' && $arr_file_upload['status'] > 300 && $arr_file_upload['status'] < 600) {
                                $err_message .= $arr_file_upload['message'];
                            }
                        }
                    }
                }
            }

            # update datacenters list
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
            $arr_datacenters_list = json_decode($datacenters_list_return, true);
            if(count($arr_datacenters_list) > 0){
                $_SESSION['datacenters_list'] = $arr_datacenters_list;
                $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
            header("location: ".CURRENT_PAGE."?do=add_success");
        }
    }
}

if($action == 'save'){
    $err_message = "";

    // make array from $_POST and format the racks section
    $arr_rack_type = $_POST['rack_type'];
    $arr_rack_row = $_POST['rack_row'];
    $arr_rack_num = $_POST['rack_num'];
    $arr_rack_label = $_POST['rack_label'];
    $arr_rack_size = $_POST['rack_size'];
    $i = 1;
    $j = 0;
    
    foreach ($arr_rack_type as $rack_detail) {
        if(isset($rack_detail) && $rack_detail != ''){
            if(is_numeric($arr_rack_num[$j])){
                $_POST['rack_type_'.$i.''] = $rack_detail;
                $_POST['rack_row_'.$i.''] = $arr_rack_row[$j];
                $_POST['rack_num_'.$i.''] = $arr_rack_num[$j];
                $_POST['rack_label_'.$i.''] = $arr_rack_label[$j];
                $_POST['rack_size_'.$i.''] = $arr_rack_size[$j];
                $i++;
            }
        }
        $j++;
    }
    $_POST['racks_count'] = $i-1;
    
    unset($_POST['rack_type']);
    unset($_POST['rack_row']);
    unset($_POST['rack_num']);
    unset($_POST['rack_label']);
    unset($_POST['rack_size']);

    // make array from $_POST and format the interconnect section
    $iconn_to = $_POST['iconn_to'];
    $iconn_speed = $_POST['iconn_speed'];
    $iconn_bandwidth = $_POST['iconn_bandwidth'];
    $iconn_provider = $_POST['iconn_provider'];
    $iconn_hops = $_POST['iconn_hops'];
    $i = 1;
    $j = 0;
    
    foreach ($iconn_to as $iconn_detail) {
        if(
                isset($iconn_detail) && $iconn_detail != '' && 
                isset($iconn_speed[$j]) && $iconn_speed[$j] != '' &&
                isset($iconn_bandwidth[$j]) && $iconn_bandwidth[$j] != '' &&
                isset($iconn_provider[$j]) && $iconn_provider[$j] != '' &&
                isset($iconn_hops[$j]) && $iconn_hops[$j] != ''
        ){
            $_POST['iconn_to_'.$i.''] = $iconn_detail;
            $_POST['iconn_speed_'.$i.''] = $iconn_speed[$j];
            $_POST['iconn_bandwidth_'.$i.''] = $iconn_bandwidth[$j];
            $_POST['iconn_provider_'.$i.''] = $iconn_provider[$j];
            $_POST['iconn_hops_'.$i.''] = $iconn_hops[$j];
            $i++;
        }
        $j++;
    }
    $_POST['iconn_count'] = $i-1;
    
    unset($_POST['iconn_to']);
    unset($_POST['iconn_speed']);
    unset($_POST['iconn_bandwidth']);
    unset($_POST['iconn_provider']);
    unset($_POST['iconn_hops']);
    
    // form field validation
    $form_validation = $utilities_library->form_fields_validation($arr_dc_data_format,$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        // avoid EOL while scanning string literal errors
        foreach ($arr_dc_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }
        
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $post_dc_data = $utilities_library->mk_json_props_array($dc_id,$_POST,$_POST);
        
        $dc_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($post_dc_data,true));
        $arr_dc_return = json_decode($dc_return,true);

        // check for final errors
        if (str_replace(' ','',$arr_dc_return['message']) != '' && $arr_dc_return['status'] > 300 && $arr_dc_return['status'] < 600) {
            $err_message .= $arr_dc_return['message'];
        }else{
            // get a list of files for the current DC ID
            $filegroup = [
                'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
                'file_class' => 'DATACENTER',
                'class_id' => $dc_id
            ];
            $arr_files_list = [];
            $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
            $arr_files_list = json_decode($files_list_return, true);
            
            foreach ($arr_dc_data_format as $fields_format){
                # for each group, list fields
                foreach ($fields_format as $fields_data){
                    if($fields_data['field_type'] == 'file'){
                        $arr_file_data = $_FILES[$fields_data['field_name']];
                        if($arr_file_data['size'] > 0){
                            // we have a file
                            // let's organize data
                            $det_str = $fields_data['field_name']."_details";
                            $arr_new_file_data['file_id'] = '';
                            $arr_new_file_data['created_by'] = '';
                            $arr_new_file_data['created_on'] = '';
                            $arr_new_file_data['modified_by'] = $_SESSION['user_data']['key'];
                            $arr_new_file_data['modified_on'] = '';
                            $arr_new_file_data['class_id'] = $dc_id;
                            $arr_new_file_data['file_type'] = $arr_file_data['type'];
                            $arr_new_file_data['file_size'] = $arr_file_data['size'];
                            $arr_new_file_data['company_id'] = $_SESSION['auth_head']['auth_head_company_id'];
                            $arr_new_file_data['file_data'] = base64_encode(file_get_contents($arr_file_data['tmp_name']));
                            $arr_new_file_data['file_description'] = $_POST[$det_str];
                            $arr_new_file_data['file_item'] = $fields_data['field_name'];
                            $arr_new_file_data['file_checksum'] = '';
                            $arr_new_file_data['file_name'] = $arr_file_data['name'];
                            $arr_new_file_data['file_class'] = 'DATACENTER';
                            // remove the existing file and load the new file
                            foreach ($arr_files_list['item_list']  as $file_data){
                                $file_info = $utilities_library->mk_array($file_data['key'],$file_data['property_list']);
                                if($file_info['file_item'] == $fields_data['field_name']){
                                    // we already have a matching file item, so we will remove it
                                    $file_id = [
                                        'file_id' => $file_data['key']
                                    ];
                                    $file_return = $rest_client->delete(WEB_SERVICE_ADDRESS.'/files',json_encode($file_id,true));
                                    $arr_file_return = json_decode($file_return,true);
                                    
                                    // check for final errors
                                    if (str_replace(' ','',$arr_file_return['message']) != '' && $arr_file_return['status'] > 300 && $arr_file_return['status'] < 600) {
                                        $err_message .= $arr_file_return['message'];
                                    }
                                }
                            }
                            // make json array
                            $post_file_data = $utilities_library->mk_json_props_array('',$arr_new_file_data,$arr_new_file_data);
                            // upload data
                            $file_upload = $rest_client->put(WEB_SERVICE_ADDRESS.'/files',json_encode($post_file_data,true));
                            $arr_file_upload = json_decode($file_upload,true);
                                
                            // check for final errors
                            if (str_replace(' ','',$arr_file_upload['message']) != '' && $arr_file_upload['status'] > 300 && $arr_file_upload['status'] < 600) {
                                $err_message .= $arr_file_upload['message'];
                            }
                        }
                    }
                }
            }
            
            # update datacenters list
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
            $arr_datacenters_list = json_decode($datacenters_list_return, true);
            if(count($arr_datacenters_list) > 0){
                $_SESSION['datacenters_list'] = $arr_datacenters_list;
                $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
        }
    }
    if($err_message == ''){
        header("location: ".CURRENT_PAGE."?do=save_success&dc_id=".$dc_id."");
    }else{
        $action = "";
    }

}


require_once(WEB_ROOT.'/incl/top.php');


?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">

    <h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_datacenters', DEFAULT_LANG); ?></h2>

    <div class="row">
        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#new_dc" role="button" class="btn btn-primary" data-toggle="modal"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_dc', DEFAULT_LANG); ?></a>
        <div class="btn-group">
        <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
            <?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_download', DEFAULT_LANG); ?> <span class="caret"></span>
          </button>
          <ul class="dropdown-menu" role="menu">
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=xml_download">XML</a></li>
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=json_download">JSON</a></li>
          </ul>
        </div>
    </div>
    <br />
    
<!-- begin search section -->

<form class="form-horizontal" role="form" name="dc_srch_form" id="dc_srch_form" action="<?php echo CURRENT_PAGE; ?>" method="get">
<div class="form-group">
<label for="u_srch" class="col-lg-2 control-label"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></label>
<div class="col-lg-6">
    <input
        type="text" 
        id="user-input" 
        class="form-control typeahead"
        placeholder="<?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search_dc_field', DEFAULT_LANG); ?>"
        autocomplete="off"
        data-provide="typeahead"
    />
    </div>
    
<input type="hidden" name="dc_id" id="dc_id" value="" /><button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></button>
</div>
</form>
    <script src="js/jquery-1.9.1.min.js"></script>
    <script src="js/bootstrap.min2.js"></script>
    <script src="js/underscore-min.js"></script>

    <script type="text/javascript">

    $(function(){
        var usrObjs = {};
        var dcNames = [];
        $(".typeahead").typeahead({
            source: function ( query, process ) {
                $.ajax({
                    url: '<?php echo CURRENT_PAGE; ?>?do=json'
                    ,cache: false
                    ,success: function(data){
                        dcObjs = {};
                        dcNames = [];
                        _.each( data, function(item, ix, list){
                            dcNames.push( item.name );
                            dcObjs[ item.name ] = item.id;
                        });
                        process( dcNames );
                    }
                });
            }
            , items: 15
            , updater: function ( selectedName ) {
                $( "#dc_id" ).val( dcObjs[ selectedName ] );
                return selectedName;
            }
        });
    });

    </script>

<br />
<!-- end search section -->

<!-- begin page features section -->

<div align="right">
<h2><a href="#dc_global_maps" role="button" data-toggle="modal"><span class="glyphicon glyphicon-globe"></span></a></h2>
</div>
<!-- end page features section -->

<!-- begin alert options -->
    <?php
        if($err_message != ''){
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
        }
        if($action == 'add_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_add_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'deactivate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_deactivate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'activate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_activate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'save_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_dc_save_success', DEFAULT_LANG)."</div>";
        }
    ?>
<!-- end alert options -->

<?php 
if($action != 'edit_dc'){
    
    if(count($arr_dc) > 0){
    
?>
<!-- display DC list table -->
<table class="table table-striped">
<tr>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_dc_name', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_dc_code', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_last_modified', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_status', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_action', DEFAULT_LANG); ?></th>
</tr>
<?php 
// check if pagination is needed

$start_rec = $pg_num * MAX_RECS_PER_PAGE;
$end_rec = $start_rec + MAX_RECS_PER_PAGE;
$arr_dc_list = $_SESSION['datacenters_list']['item_list'];
$no_paging = false;
if($dc_id != ''){
    // dc search; display only that record
    $arr_dc_search = [];
    foreach ($_SESSION['datacenters_list']['item_list'] as $d_list){
        if($d_list['key'] == $dc_id){
            $arr_dc_search[0] = $d_list;
        }
    }
    if(count($arr_dc_search) > 0){
        $arr_dc_list = $arr_dc_search;
        $no_paging = true;
    }else{
        $arr_dc_list = $_SESSION['datacenters_list']['item_list'];
    }
}
if(count($arr_dc_list) <= MAX_RECS_PER_PAGE){
    $no_paging = true;
}else if($start_rec > count($arr_dc_list)){
    $start_rec = 0;
    $end_rec = $start_rec + MAX_RECS_PER_PAGE;
    $pg_num = 0;
}

print $utilities_library->make_dc_table($arr_dc_list, DEFAULT_LANG, CURRENT_PAGE, $start_rec, $end_rec, $arr_labels, $pg_num, $arr_dc_data_format, $_SESSION['datacenters_list']);

?>

</table>
<!-- end display DC list table -->

<!-- begin display DC edit form -->
<?php 
    }
}else{ 

    $is_dc = false;
    $toedit_dc = [];
    foreach ($_SESSION['datacenters_list']['item_list'] as $dc_data){
        if ($dc_data['key'] == $dc_id){
            $is_dc = true;
            $toedit_dc = $utilities_library->mk_array($dc_data['key'],$dc_data['property_list']);
        }
    }
    if ($is_dc == false){
        print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$formatting_library->make_lang_label($arr_labels, 'lbl_err_no_such_datacenter', DEFAULT_LANG)."</div>";
    }else{
?>
<form action="<?php echo CURRENT_PAGE; ?>?do=save&dc_id=<?php echo $dc_id; ?>" method="post" enctype="multipart/form-data">

     <!--<div class="tabbable col-lg-8"> Only required for left/right tabs -->

    <?php 
    $active_tab_info = "class=\"active\"";
    $active_tab_det = "";
    $active_tab_rac = "";
    $active_tab_con = "";
    $active_tab_doc = "";
    $active_pan_info = "tab-pane active";
    $active_pan_det = "tab-pane";
    $active_pan_rac = "tab-pane";
    $active_pan_con = "tab-pane";
    $active_pan_doc = "tab-pane";
    if($_GET['at'] == 'info'){
        $active_tab_info = "class=\"active\"";
        $active_tab_det = "";
        $active_tab_doc = "";
        $active_tab_rac = "";
        $active_tab_con = "";
        $active_pan_info = "tab-pane active";
        $active_pan_det = "tab-pane";
        $active_pan_rac = "tab-pane";
        $active_pan_con = "tab-pane";
        $active_pan_doc = "tab-pane";
    }else if($_GET['at'] == 'det'){
        $active_tab_info = "";
        $active_tab_det = "class=\"active\"";
        $active_tab_doc = "";
        $active_tab_rac = "";
        $active_tab_con = "";
        $active_pan_info = "tab-pane";
        $active_pan_det = "tab-pane active";
        $active_pan_rac = "tab-pane";
        $active_pan_con = "tab-pane";
        $active_pan_doc = "tab-pane";
    }else if($_GET['at'] == 'rac'){
        $active_tab_info = "";
        $active_tab_det = "";
        $active_tab_rac = "class=\"active\"";
        $active_tab_doc = "";
        $active_tab_con = "";
        $active_pan_info = "tab-pane";
        $active_pan_det = "tab-pane";
        $active_pan_rac = "tab-pane active";
        $active_pan_con = "tab-pane";
        $active_pan_doc = "tab-pane";
    }else if($_GET['at'] == 'doc'){
        $active_tab_info = "";
        $active_tab_det = "";
        $active_tab_rac = "";
        $active_tab_doc = "class=\"active\"";
        $active_tab_con = "";
        $active_pan_info = "tab-pane";
        $active_pan_det = "tab-pane";
        $active_pan_rac = "tab-pane";
        $active_pan_con = "tab-pane";
        $active_pan_doc = "tab-pane active";
    }else if($_GET['at'] == 'con'){
        $active_tab_info = "";
        $active_tab_det = "";
        $active_tab_rac = "";
        $active_tab_doc = "";
        $active_tab_con = "class=\"active\"";
        $active_pan_info = "tab-pane";
        $active_pan_det = "tab-pane";
        $active_pan_rac = "tab-pane";
        $active_pan_con = "tab-pane active";
        $active_pan_doc = "tab-pane";
    }else{
        $active_tab_info = "class=\"active\"";
        $active_tab_det = "";
        $active_tab_rac = "";
        $active_tab_doc = "";
        $active_tab_con = "";
        $active_pan_info = "tab-pane active";
        $active_pan_det = "tab-pane";
        $active_pan_rac = "tab-pane";
        $active_pan_con = "tab-pane";
        $active_pan_doc = "tab-pane";
    }
    ?>
    
    <ul class="nav nav-tabs">
    <li <?php echo $active_tab_info; ?>><a href="#edc_info" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_info', DEFAULT_LANG); ?></a></li>
    <li <?php echo $active_tab_det; ?>><a href="#edc_detail" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_details', DEFAULT_LANG); ?></a></li>
    <li <?php echo $active_tab_con; ?>><a href="#edc_conn" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_interconnect', DEFAULT_LANG); ?></a></li>
    <li <?php echo $active_tab_det; ?>><a href="#edc_racks" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_racks', DEFAULT_LANG); ?></a></li>
    <li <?php echo $active_tab_doc; ?>><a href="#edc_docs" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_docs', DEFAULT_LANG); ?></a></li>
    </ul>
    <div class="tab-content">
    <br />
    <div class="<?php echo $active_pan_info; ?>" id="edc_info">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['info'], DEFAULT_LANG, $toedit_dc, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="<?php echo $active_pan_det; ?>" id="edc_detail">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['details'], DEFAULT_LANG, $toedit_dc, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="<?php echo $active_pan_con; ?>" id="edc_conn">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_iconnect_form($arr_labels,DEFAULT_LANG, $toedit_dc,$arr_dc);
    print "</div>";
    ?>
    </div>
    <div class="<?php echo $active_pan_rac; ?>" id="edc_racks">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_rac_form($arr_labels,DEFAULT_LANG, $toedit_dc);
    print "</div>";
    ?>
    </div>
    <div class="<?php echo $active_pan_doc; ?>" id="edc_docs">
    <?php
    print "<div class=\"span4\">";
    // display the current documents
    // and let the user decide if they want to update
    
    $filegroup = [
    'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
    'file_class' => 'DATACENTER',
    'class_id' => $dc_id
    ];
    $arr_files_list = [];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
    
    if ((str_replace(' ','',$files_list_return['message']) != '' && $files_list_return['status'] > 300 && $files_list_return['status'] < 600) || (str_replace(' ','',$files_list_return['message']) != '' && $files_list_return['status'] > 300 && $files_list_return['status'] < 600)) {
        print $files_list_return['message'];
    }else{
    
        $arr_files_list = json_decode($files_list_return, true);

        if(count($arr_files_list['item_list']) > 0){
            print "<div class=\"panel panel-primary\">";
            print "<div class=\"panel-heading\">".$formatting_library->make_lang_label($arr_labels,'lbl_dc_current_files',DEFAULT_LANG)."</div>";
            print "<div class=\"panel-body\">";
            print "<p>".$formatting_library->make_lang_label($arr_labels,'lbl_dc_current_files_desc',DEFAULT_LANG)."</p>";
            print "</div>";

            print "<table class=\"table\">";
    
            foreach ($arr_files_list['item_list']  as $file_data){
                $file_info = $utilities_library->mk_array($file_data['key'],$file_data['property_list']);
                # get the label for the current file:
                $file_label = $arr_dc_data_format['documents'][$file_info['file_item']]['field_label'];
                
                print "<tr>";
                print "<td valign=\"top\"><b>".$formatting_library->make_lang_label($arr_labels,$file_label,DEFAULT_LANG)."</b></td>";
                print "<td valign=\"top\">".$file_info['file_name']."<br />".$toedit_dc[$file_info['file_item']."_details"]."</td>";
                print "<td valign=\"top\">".$file_info['file_size']."b</td>";
                print "<td valign=\"top\">".$utilities_library->mk_dt($file_info['modified_on'],'Y-m-d H:i:s.u',DATETIME_FORMAT)."</td>";
                print "<td valign=\"top\"><a href=\"getfile.php?file_id=".$file_info['key']."\"><span class=\"glyphicon glyphicon-download-alt\"></span></a> | <a href=\"".CURRENT_PAGE."?do=file_delete&dc_id=".$dc_id."&file_id=".$file_info['key']."&at=doc&pg=".$pg_num."\" onclick=\"return confirm('".$formatting_library->make_lang_label($arr_labels,'lbl_dc_file_remove_confirm',DEFAULT_LANG)."');\"><span class=\"glyphicon glyphicon-remove\"></span></a></td>";
                print "</tr>";
            }
            
            print "</table>";
            print "</div>";
        }else{
            print "<div class=\"panel panel-danger\">";
            print "<div class=\"panel-heading\">".$formatting_library->make_lang_label($arr_labels,'lbl_dc_current_files',DEFAULT_LANG)."</div>";
            print "<div class=\"panel-body\">";
            print "<p>".$formatting_library->make_lang_label($arr_labels,'lbl_dc_current_files_no_files',DEFAULT_LANG)."</p>";
            print "</div>";
            print "</div>";
        }
        

    }
    
    print "<div class=\"panel panel-success\">";
    print "<div class=\"panel-heading\">".$formatting_library->make_lang_label($arr_labels,'lbl_dc_new_files',DEFAULT_LANG)."</div>";
    print "<div class=\"panel-body\">";
    print "<p>".$formatting_library->make_lang_label($arr_labels,'lbl_dc_new_files_desc',DEFAULT_LANG)."</p>";
    print "</div>";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['documents'], DEFAULT_LANG, $toedit_dc, $_POST, $form_validation);
    print "</div>";
    print "</div>";
    ?>
    </div>
    </div>

    <button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels,'lbl_btn_save',DEFAULT_LANG); ?></button>

</form>
<?php 
    }
} 
?>
<!-- end display DC edit form -->


<!-- begin pagination section -->
<?php 
if (count($arr_dc) > 0){
    if($no_paging == false && $action != 'edit_dc'){
        print $utilities_library->make_pagination(count($arr_dc_list),$pg_num,CURRENT_PAGE,$arr_labels);
    }else if($dc_id != '' || $action == 'edit_dc'){
        print "<ul class=\"pagination pagination-sm\">";
        print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
        print "</ul>";
    }
}
?>
<!-- end pagination section -->

<!-- display add dc section -->

<form action="<?php echo CURRENT_PAGE; ?>?do=add" method="post" enctype="multipart/form-data">

<div class="modal fade" id="new_dc" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
<div class="modal-dialog">
<div class="modal-content">

<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
<h3 id="myModalLabel"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_new_dc', DEFAULT_LANG); ?></h3>
</div>
<div class="modal-body">
<?php 
if($err_message != ''){
    print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
}
?>

<div class="tabbable"> <!-- Only required for left/right tabs -->
<ul class="nav nav-tabs">
    <li class="active"><a href="#dc_info" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_info', DEFAULT_LANG); ?></a></li>
    <li><a href="#dc_detail" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_details', DEFAULT_LANG); ?></a></li>
    <li><a href="#dc_docs" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_dc_docs', DEFAULT_LANG); ?></a></li>
</ul>
<br />
<div class="tab-content">
    <div class="tab-pane active" id="dc_info">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['info'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="dc_detail">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['details'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="dc_docs">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_dc_data_format['documents'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>

</div> <!-- end tab content -->
</div> <!-- end tabbable -->
</div> <!-- end modal body -->

<div class="modal-footer">
<button class="btn btn-danger" data-dismiss="modal" aria-hidden="true"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_cancel', DEFAULT_LANG); ?></button>
<button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_dc', DEFAULT_LANG); ?></button>
</div> <!-- end modal footer -->

</div> <!-- end modal content -->
</div> <!-- end modal dialog -->
</div> <!-- end modal fade -->
</form>

<!-- end display dc add section -->


<!-- display dc map section -->


<style>
#map-canvas {
    height: 500px;
    width: 500px;
    margin: 10px;
    padding: 10px
}
</style>
<script src="https://maps.googleapis.com/maps/api/js?sensor=false"></script>
<script>

    function initialize() {
        var mapOptions = {
            zoom: <?php echo MAP_ZOOM; ?>,
            center: new google.maps.LatLng(<?php echo MAP_CENTER_LAT; ?>, <?php echo MAP_CENTER_LONG; ?>)
        }
        var map = new google.maps.Map(document.getElementById('map-canvas'),mapOptions);
        setMarkers(map);
        $('#dc_global_maps').on('shown', function () {
            google.maps.event.trigger(map, "resize");
            map.setCenter(new google.maps.LatLng(<?php echo MAP_CENTER_LAT; ?>, <?php echo MAP_CENTER_LONG; ?>));
        });
    }

    var image = {
        url: 'img/datacenter.png',
        size: new google.maps.Size(32, 32),
        origin: new google.maps.Point(0,0),
        anchor: new google.maps.Point(0, 32)
    };
    
    var shape = {
        coord: [1, 1, 1, 20, 18, 20, 18 , 1],
        type: 'poly'
    };
    

    function setMarkers(map) {
        $.getJSON('<?php echo CURRENT_PAGE; ?>?do=json_map', function(data) {
            for (var x = 0; x < data.length; x++) {
                var datacenter = data[x];
                var myLatLng = new google.maps.LatLng(datacenter.datacenter_lat, datacenter.datacenter_long);
                var marker = new google.maps.Marker({
                    position: myLatLng,
                    map: map,
                    icon: image,
                    shape: shape,
                    title: datacenter.datacenter_name,
                    zIndex: x+1
                });
                var contentString = '<b>' + datacenter.datacenter_name + ' (' + datacenter.datacenter_code + ')</b>' +
                '<div>' + datacenter.datacenter_address + '</div>';
                createInfoWindow(map, marker, contentString);
            }
        });
    }
    
    var infoWindow = new google.maps.InfoWindow({maxWidth: 200});
    
    function createInfoWindow(map, marker, contentString) {
        google.maps.event.addListener(marker, 'click', function () {
            infoWindow.setContent(contentString);
            infoWindow.open(map, marker);
        });
    }

    google.maps.event.addDomListener(window, 'load', initialize);

</script>


<div class="modal fade" id="dc_global_maps" tabindex="-1" role="dialog" aria-labelledby="MapModalLabel" aria-hidden="true">
<div class="modal-dialog">
<div class="modal-content">
<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
<h3 id="MapModalLabel"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_dc_global_map', DEFAULT_LANG); ?></h3>
</div>
<div class="modal-body">

<div id="map-canvas"></div>

<hr />
<?php 
echo $utilities_library->make_all_dc_interconnect_svg($_SESSION['datacenters_list']);
?>
</div> <!-- end modal body -->



</div> <!-- end modal content -->
</div> <!-- end modal dialog -->
</div> <!-- end modal fade -->

<!-- end display dc map section -->


<?php
$no_js = true;
require_once(WEB_ROOT.'/incl/bottom.php');

?>
