<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Index and welcome login screen
* 
*                  The only true requirement of this page is the login screen. The validation 
*                  occurs against the API and the following sessions are being set:
* 
*                      auth_head - Header authentication session for all REST requests
*                      user_data - User information session
*                      company_data - Company information session
*                      company_data_create_dt - company_data session creation date
* 
*                  Note:
*                  The RSS news feed is being configured in infratrack_WEB.ini file and NOT on this page.
* 
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

if (isset($_SESSION['user_data'])){
    header("location: ".WEB_ADDRESS."dashboard.php");
}

// clean-up WEB_ADDRESS
$web_base = str_replace($_SERVER["CONTEXT_PREFIX"],'',WEB_ADDRESS);
$web_base = str_replace('http://','',$web_base);
$web_base = str_replace('https://','',$web_base);
$web_base = explode(":",$web_base);

if ($_SERVER["HTTP_HOST"] != $web_base[0] && $_SERVER["HTTP_HOST"] != str_replace('/','',$web_base[0])){
    header("location: ".WEB_ADDRESS."");
}

require_once(WEB_ROOT.'/lib/rest_client.php');

// action
$err_message = '';

if(str_replace(' ','',$_POST['user_name']) != '' && str_replace(' ','',$_POST['password']) != ''){
    // login the user

    $company_data = ['company_id' => COMPANY_ID];
    $json_company_data = json_encode($company_data);
    $user_login = [
                        'auth_head_user_name'=>str_replace(' ','',$_POST['user_name']),
                        'auth_head_password'=>str_replace(' ','',$_POST['password']),
                        'auth_head_company_id'=>COMPANY_ID
                 ];

    $rest_client = new rest_client($user_login,'');

    // to validate, we will try and get the user based on header
    $user_return = $rest_client->get(WEB_SERVICE_ADDRESS.'/user');
    $arr_usr_return = json_decode($user_return, true);

    // and let's also get the company data
    $company_return = $rest_client->post(WEB_SERVICE_ADDRESS.'/company',$json_company_data);
    $arr_co_return = json_decode($company_return, true);
    if ((str_replace(' ','',$arr_usr_return['message']) != '' && $arr_usr_return['status'] > 300 && $arr_usr_return['status'] < 600) || (str_replace(' ','',$arr_co_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
        //$err_message = 'Invalid Login';
        $err_message = $arr_usr_return['message'];
    }else{
        // user valid; create login session
        $_SESSION['auth_head'] = $user_login;
        $_SESSION['user_data'] = $utilities_library->mk_array($arr_usr_return['key'],$arr_usr_return['property_list']);
        $_SESSION['company_data'] = $utilities_library->mk_array($arr_co_return['key'],$arr_co_return['property_list']);
        $_SESSION['company_data_create_dt'] = gmdate("Y-m-d H:i:s", time());

        header("location: ".WEB_ADDRESS."dashboard.php");
    }
}


require_once(WEB_ROOT.'/incl/top.php');

?>


<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>


    <div class="indexpg">
      <div class="container">

        <div class='Pane'>
          <div class='Sub'>
            <div class='Below'>
              <div class='Info'>

                <div class='Item' id='SectionOne'>
                  <h2 class='Left'>Welcome!</h2>
                    <div class='Right'>
                      <p><strong><?php echo APP_NAME; ?></strong> is a fully scalable and redundant management interface for your IT infrastructure. Tools included are:</p>
                      <ul>
                        <li><strong>CMDB</strong> [Computer Management Database] for your servers, routers, switches, storage arrays and any device connected in your network</li> 
                        <li><strong>Datacenters</strong> details, location, capacity, power and connectivity</li>
                        <li><strong>Users</strong> management and access controls</li>
                        <li><strong>Relation</strong> between your inrastructure and applications to predict and asses impact of scheduled and unscheduled outages</li>
                      </ul>
                      <p><strong><?php echo APP_NAME; ?></strong> allows you to perform better by having a always-on good overview of your infrastructure</p>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>

      </div>
    </div>

    <div class="container">
      <div class="row">
        <div class="col-lg-4">
          <h2>News</h2>
<?php
    $rss = new DOMDocument();
    $rss->load(RSS_FEED);
    $feed = array();
    foreach ($rss->getElementsByTagName('item') as $node) {
        $item = array (
            'title' => $node->getElementsByTagName('title')->item(0)->nodeValue,
            'desc' => $node->getElementsByTagName('description')->item(0)->nodeValue,
            'link' => $node->getElementsByTagName('link')->item(0)->nodeValue,
            'date' => $node->getElementsByTagName('pubDate')->item(0)->nodeValue,
        );
        array_push($feed, $item);
    }
    $i = 0;
    foreach($feed as $feed_data) {
        $title = str_replace(' & ', ' &amp; ', $feed_data['title']);
        $link = $feed_data['link'];
        $description = $feed_data['desc'];
        $date = date('Y-m-d', strtotime($feed_data['date']));
        if($i < RSS_ITEMS){
            echo "<p><strong><a href=\"".$link."\" target=\"_blank\">".$title."</a> </strong>";
            echo "[<small><em>".$date."</em></small>]</p>";
            echo "<p>".substr($description,0,100)." ...</p>";
            echo "<hr />";
        }
        $i++;
    }

?>

        </div>
        <div class="col-lg-4">
        
            <div class="container">

              <form class="form-signin" action="<?php echo WEB_ADDRESS; ?>" method="post">
                <h2 class="form-signin-heading">Login</h2>
                <input type="text" class="form-control" placeholder="UserName" name="user_name" autofocus><br />
                <input type="password" class="form-control" placeholder="Password" name="password" maxlength="20"><br />
                    <?php
                      if($err_message != ''){
                        print "<div class=\"alert alert-danger\">".$err_message."</div>";
                      }
                    ?>
                <button class="btn btn-success" type="submit">Login</button>
              </form>
            </div>
        </div>

        <div class="col-lg-4">
          <h2>Documentation</h2>
          <p><a class="btn btn-primary" href="javascript:PopupWindow('./doc/',500,500,0)">View documents &raquo;</a></p>
        </div>
      </div>


<?php

require_once(WEB_ROOT.'/incl/bottom.php');
?>
