<?php

/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Password encryption module
*                  For security purposes, the device account passwords are encrypted 
*                  before transmission back and from the API/Database engine. This protects 
*                  your information while at rest or in flight. To do so, aes-256 
*                  encryption keys MUST be generated after a new installation of 
*                  InfraTrack Web portal.

*                  Generating keys:
*                  On a Linux system with OpenSSL pre-installed, execute command:
* 
*                  openssl enc -aes-256-cbc -k /dev/urandom -P -md sha1
* 
*                  As example, the above command will result in:
* 
*                  salt=5D2862725AD5CA2B
*                  key=E46EF334C839C1E1BC76F0074271A0451705593FB7E04D9D4EC6A56D46839B7D
*                  iv =F89B1B6A80A867EF0141E5E1734E3813
* 
*                  From the result, copy the KEY value and locate the public $arr_crypto_keys 
*                  variable in lib/enc_module.php file, enc_library class.
* 
*                  The variable will have multiple entries like:
* 
*                  'grp_01' => [
*                      'key_name'  => 'Admin Group',
*                      'key_value' => 'E46EF334C839C1E1BC76F0074271A0451705593FB7E04D9D4EC6A56D46839B7D',
*                      'key_pass'  => 'KuL4rT78-33V9'
*                  ]
* 
*                  Replace the key_value value with your new generated key.
* 
*                  Additionally, change the key_name and use a strong password for key_pass value.
* 
*                  Repeat this process for all keys required.
* 
*                  Also, ensure that you increment by 1 (+1) all "grp" array groups (e.g.: grp_01 
*                  followed by grp_02 followed by grp_03, etc.)
* 
*                  Once all keys are generated, distribute the file to all portal nodes in your 
*                  environment and make sure that the keys are protected by changing ownership and 
*                  read permissions on the lib/enc_module.php file:
* 
*                  sudo chown www-data:www-data /srv/infratrack_www/lib/enc_module.php
*                  sudo chmod 400 /srv/infratrack_www/lib/enc_module.php
* 
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

class enc_library {
    
    # Make key in Linux:
    # openssl enc -aes-256-cbc -k somelongstringwithnomeaninghere -P -md sha1
    public $arr_crypto_keys =
            [
                'grp_01' => [
                    'key_name' => 'Admin Group',
                    'key_value'=> '0000000000000000000000000000000000000000000000000000000000000000',
                    'key_pass' => 'BLBEPFnPqx3b82y9'
                ],
                'grp_02' => [
                    'key_name' => 'Network Group',
                    'key_value' => '0000000000000000000000000000000000000000000000000000000000000000',
                    'key_pass' => 'UG5EwC4UWpuBztUX'
                ],
                'grp_03' => [
                    'key_name' => 'Application Group',
                    'key_value' => '0000000000000000000000000000000000000000000000000000000000000000',
                    'key_pass' => 'B4cUy21fc4eH5Hsg'
                ],
                'grp_04' => [
                    'key_name' => 'DBA Group',
                    'key_value' => '0000000000000000000000000000000000000000000000000000000000000000',
                    'key_pass' => 'LFwvAqn41sb27yj0'
                ]
            ];
    

    function enc_pwd($decrypted, $password, $salt) {
        $key = hash('SHA256', $salt . $password, true);
        srand(); $iv = mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_RIJNDAEL_128, MCRYPT_MODE_CBC), MCRYPT_RAND);
        if (strlen($iv_base64 = rtrim(base64_encode($iv), '=')) != 22) return false;
        $encrypted = base64_encode(mcrypt_encrypt(MCRYPT_RIJNDAEL_128, $key, $decrypted . md5($decrypted), MCRYPT_MODE_CBC, $iv));
        return $iv_base64 . $encrypted;
    }
    
    function dec_pwd($encrypted, $password, $salt) {
        $key = hash('SHA256', $salt . $password, true);
        $iv = base64_decode(substr($encrypted, 0, 22) . '==');
        $encrypted = substr($encrypted, 22);
        $decrypted = rtrim(mcrypt_decrypt(MCRYPT_RIJNDAEL_128, $key, base64_decode($encrypted), MCRYPT_MODE_CBC, $iv), "\0\4");
        $hash = substr($decrypted, -32);
        $decrypted = substr($decrypted, 0, -32);
        if (md5($decrypted) != $hash) return false;
        return $decrypted;
    }
    
}


$enc_library = new enc_library();

?>
