<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Group of form fields
* 
*                  Example: 
*                  Create the label in your language locale file (e.g.: lbl_user_middle_name)
*                  Add the following object to arr_user_data_format list:
* 
*                  'user_middle_name' => [
*                  'field_label' => 'lbl_user_middle_name',
*                  'field_name' => 'user_middle_name',
*                  'field_default_val' => '',
*                  'field_readonly' => 'false',
*                  'field_length' => '20',
*                  'field_type' => 'alpha',
*                  'field_validate' => 'true'
*                  ]
*                  
*                  The above object will create a new editable field in the users management 
*                  form which will accept alpha characters up to 20 in length and will validate 
*                  upon submission.
* 
* 
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

$arr_user_data_format = [
        'personal' => [
            'personal_email' => [
                'field_label' => 'lbl_personal_email',
                'field_name' => 'personal_email',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '150',
                'field_type' => 'email',
                'field_validate' => true
            ],
            'personal_mobile_phone' => [
                'field_label' => 'lbl_personal_cellphone',
                'field_name' => 'personal_mobile_phone',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'phone',
                'field_validate' => true
            ],
            'home_phone' => [
                'field_label' => 'lbl_personal_phone',
                'field_name' => 'home_phone',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'phone',
                'field_validate' => false
            ],
            'home_address1' => [
                'field_label' => 'lbl_personal_address1',
                'field_name' => 'home_address1',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'home_address2' => [
                'field_label' => 'lbl_personal_address2',
                'field_name' => 'home_address2',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '50',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'home_city' => [
                'field_label' => 'lbl_personal_city',
                'field_name' => 'home_city',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'home_region' => [
                'field_label' => 'lbl_personal_region',
                'field_name' => 'home_region',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'home_postcode' => [
                'field_label' => 'lbl_personal_postcode',
                'field_name' => 'home_postcode',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'home_country' => [
                'field_label' => 'lbl_personal_country',
                'field_name' => 'home_country',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '80',
                'field_type' => 'alpha',
                'field_validate' => true
            ]
        ],
        'professional' => [
            'work_email' => [
                'field_label' => 'lbl_office_email',
                'field_name' => 'work_email',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '150',
                'field_type' => 'email',
                'field_validate' => false
            ],
            'work_mobile_phone' => [
                'field_label' => 'lbl_office_cellphone',
                'field_name' => 'work_mobile_phone',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'phone',
                'field_validate' => false
            ],
            'work_phone' => [
                'field_label' => 'lbl_office_phone',
                'field_name' => 'work_phone',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'phone',
                'field_validate' => false
            ],
            'work_address1' => [
                'field_label' => 'lbl_office_address1',
                'field_name' => 'work_address1',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'work_address2' => [
                'field_label' => 'lbl_office_address2',
                'field_name' => 'work_address2',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '50',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'work_city' => [
                'field_label' => 'lbl_office_city',
                'field_name' => 'work_city',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'work_region' => [
                'field_label' => 'lbl_office_region',
                'field_name' => 'work_region',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'work_postcode' => [
                'field_label' => 'lbl_office_postcode',
                'field_name' => 'work_postcode',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '20',
                'field_type' => 'any',
                'field_validate' => false
            ],
            'work_country' => [
                'field_label' => 'lbl_office_country',
                'field_name' => 'work_country',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '80',
                'field_type' => 'alpha',
                'field_validate' => true
            ]
        ],
        'account' => [
            'user_name' => [
                'field_label' => 'lbl_username',
                'field_name' => 'user_name',
                'field_default_val' => '',
                'field_readonly' => true,
                'field_length' => '20',
                'field_type' => 'alphanum',
                'field_validate' => true
            ],
            'password' => [
                'field_label' => 'lbl_password',
                'field_name' => 'password',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '36',
                'field_type' => 'password',
                'field_validate' => true
            ],
            'first_name' => [
                'field_label' => 'lbl_first_name',
                'field_name' => 'first_name',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '50',
                'field_type' => 'alpha',
                'field_validate' => true
            ],
            'last_name' => [
                'field_label' => 'lbl_last_name',
                'field_name' => 'last_name',
                'field_default_val' => '',
                'field_readonly' => false,
                'field_length' => '100',
                'field_type' => 'alpha',
                'field_validate' => true
            ],
            'access_level' => [
                'field_label' => 'lbl_access_level',
                'field_name' => 'access_level',
                'field_default_val' => $arr_access_level,
                'field_readonly' => false,
                'field_length' => '',
                'field_type' => 'select',
                'field_validate' => true
            ],
            'timezone' => [
                'field_label' => 'lbl_timezone',
                'field_name' => 'timezone',
                'field_default_val' => $arr_timezones,
                'field_readonly' => false,
                'field_length' => '',
                'field_type' => 'select',
                'field_validate' => true
            ],
            'lang_env' => [
                'field_label' => 'lbl_language',
                'field_name' => 'lang_env',
                'field_default_val' => $arr_languages,
                'field_readonly' => false,
                'field_length' => '',
                'field_type' => 'select',
                'field_validate' => true
            ]
        ]
    
];

$arr_dc_data_format = [
    'info' => [
        'dc_name' => [
            'field_label' => 'lbl_dc_name',
            'field_name' => 'datacenter_name',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'dc_code' => [
            'field_label' => 'lbl_dc_code',
            'field_name' => 'datacenter_code',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'dc_address' => [
            'field_label' => 'lbl_dc_address',
            'field_name' => 'datacenter_address',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '300',
            'field_type' => 'any',
            'field_validate' => true
        ]
    ],
    'details' => [
        'private_net_block' => [
            'field_label' => 'lbl_dc_priv_netblock',
            'field_name' => 'priv_netblock',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'public_net_block' => [
            'field_label' => 'lbl_dc_public_netblock',
            'field_name' => 'public_netblock',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'net_speed' => [
            'field_label' => 'lbl_dc_net_speed',
            'field_name' => 'net_speed',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'bandwidth' => [
            'field_label' => 'lbl_dc_bandwidth',
            'field_name' => 'bandwidth',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'dc_power' => [
            'field_label' => 'lbl_dc_power',
            'field_name' => 'dc_power',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ]
    ],
    'documents' => [
        'dc_intro' => [
            'field_label' => 'lbl_dc_intro',
            'field_name' => 'dc_intro',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'file',
            'field_validate' => false
        ],
        'dc_intro_details' => [
            'field_label' => 'lbl_dc_intro_details',
            'field_name' => 'dc_intro_details',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'dc_contract' => [
            'field_label' => 'lbl_dc_contract',
            'field_name' => 'dc_contract',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'file',
            'field_validate' => false
        ],
        'dc_contract_details' => [
            'field_label' => 'lbl_dc_contract_details',
            'field_name' => 'dc_contract_details',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'dc_setup' => [
            'field_label' => 'lbl_dc_setup',
            'field_name' => 'dc_setup',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'file',
            'field_validate' => false
        ],
        'dc_setup_details' => [
            'field_label' => 'lbl_dc_setup_details',
            'field_name' => 'dc_setup_details',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'dc_map' => [
            'field_label' => 'lbl_dc_map',
            'field_name' => 'dc_map',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'file',
            'field_validate' => false
        ],
        'dc_map_details' => [
            'field_label' => 'lbl_dc_map_details',
            'field_name' => 'dc_map_details',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'cage_access' => [
            'field_label' => 'lbl_dc_cage_access',
            'field_name' => 'cage_access',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'file',
            'field_validate' => false
        ],
        'cage_access_details' => [
            'field_label' => 'lbl_dc_cage_access_details',
            'field_name' => 'cage_access_details',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ]
    ]
];


$arr_template_data_format = [
    'info' => [
        'template_name' => [
            'field_label' => 'lbl_template_name',
            'field_name' => 'template_name',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'template_code' => [
            'field_label' => 'lbl_template_code',
            'field_name' => 'template_code',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'textarea',
            'field_validate' => true
        ]
    ]
];

$arr_device_data_format = [
    'device' => [
        'device_name' => [
            'field_label' => 'lbl_device_name',
            'field_name' => 'device_name',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_vm_name' => [
            'field_label' => 'lbl_device_vm_name',
            'field_name' => 'device_vm_name',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_dc_location' => [
            'field_label' => 'lbl_device_dc_location',
            'field_name' => 'datacenter_id',
            'field_default_val' => 'datacenters_list',
            'field_readonly' => false,
            'field_length' => '',
            'field_type' => 'select',
            'field_validate' => true
        ],
        'device_rack_location' => [
            'field_label' => 'lbl_device_rack_location',
            'field_name' => 'device_rack_location',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '8',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_use' => [
            'field_label' => 'lbl_device_use',
            'field_name' => 'device_use',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_purpose' => [
            'field_label' => 'lbl_device_purpose',
            'field_name' => 'device_purpose',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '500',
            'field_type' => 'textarea',
            'field_validate' => false
        ],
        'active_yn' => [
            'field_label' => 'lbl_device_purpose',
            'field_name' => 'active_yn',
            'field_default_val' => ['True'=>'Yes','False'=>'No'],
            'field_readonly' => false,
            'field_length' => '500',
            'field_type' => 'select',
            'field_validate' => false
        ],
        'device_primary_support_person' => [
            'field_label' => 'lbl_device_primary_support_person',
            'field_name' => 'device_primary_support_person',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'alpha',
            'field_validate' => true
        ],
        'device_secondary_support_person' => [
            'field_label' => 'lbl_device_secondary_support_person',
            'field_name' => 'device_secondary_support_person',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'alpha',
            'field_validate' => false
        ],
        'device_vendor_info' => [
            'field_label' => 'lbl_device_vendor_info',
            'field_name' => 'device_vendor_info',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '200',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_implementation_date' => [
            'field_label' => 'lbl_device_implementation_date',
            'field_name' => 'device_implementation_date',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '10',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_decomission_date' => [
            'field_label' => 'lbl_device_decomission_date',
            'field_name' => 'device_decomission_date',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '10',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_notes' => [
            'field_label' => 'lbl_device_notes',
            'field_name' => 'device_notes',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '500',
            'field_type' => 'textarea',
            'field_validate' => false
        ],
        'device_vm_hwid' => [
            'field_label' => 'lbl_device_vm_hwid',
            'field_name' => 'device_vm_hwid',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_asset_tag' => [
            'field_label' => 'lbl_device_asset_tag',
            'field_name' => 'device_asset_tag',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_esx_host' => [
            'field_label' => 'lbl_device_esx_host',
            'field_name' => 'device_esx_host',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_hostname' => [
            'field_label' => 'lbl_device_hostname',
            'field_name' => 'device_hostname',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_domain' => [
            'field_label' => 'lbl_device_domain',
            'field_name' => 'device_domain',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_cpu_cores' => [
            'field_label' => 'lbl_device_cpu_cores',
            'field_name' => 'device_cpu_cores',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '4',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_cpu_sockets' => [
            'field_label' => 'lbl_device_cpu_sockets',
            'field_name' => 'device_cpu_sockets',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '5',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_cpu_info' => [
            'field_label' => 'lbl_device_cpu_info',
            'field_name' => 'device_cpu_info',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_memory' => [
            'field_label' => 'lbl_device_memory',
            'field_name' => 'device_memory',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '20',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_storage' => [
            'field_label' => 'lbl_device_storage',
            'field_name' => 'device_storage',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '20',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_primary_ip' => [
            'field_label' => 'lbl_device_primary_ip',
            'field_name' => 'device_primary_ip',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_primary_ip_gateway' => [
            'field_label' => 'lbl_device_primary_ip_gateway',
            'field_name' => 'device_primary_ip_gateway',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_addl_ips' => [
            'field_label' => 'lbl_device_addl_ips',
            'field_name' => 'device_addl_ips',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_os' => [
            'field_label' => 'lbl_device_os',
            'field_name' => 'device_os',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '150',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_tag' => [
            'field_label' => 'lbl_device_tag',
            'field_name' => 'device_tag',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_manufacturer' => [
            'field_label' => 'lbl_device_manufacturer',
            'field_name' => 'device_manufacturer',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_model' => [
            'field_label' => 'lbl_device_model',
            'field_name' => 'device_model',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => true
        ],
        'device_warranty_expiration' => [
            'field_label' => 'lbl_device_warranty_expiration',
            'field_name' => 'device_warranty_expiration',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '10',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_power_consumption' => [
            'field_label' => 'lbl_device_power_consumption',
            'field_name' => 'device_power_consumption',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '30',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_u_position' => [
            'field_label' => 'lbl_device_u_position',
            'field_name' => 'device_u_position',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '5',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_u_size' => [
            'field_label' => 'lbl_device_u_size',
            'field_name' => 'device_u_size',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '5',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_net_ports' => [
            'field_label' => 'lbl_device_net_ports',
            'field_name' => 'device_net_ports',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '5',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_net_ports_speed' => [
            'field_label' => 'lbl_device_net_ports_speed',
            'field_name' => 'device_net_ports_speed',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '20',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_fiber_ports' => [
            'field_label' => 'lbl_device_fiber_ports',
            'field_name' => 'device_fiber_ports',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '5',
            'field_type' => 'num',
            'field_validate' => true
        ],
        'device_fiber_speed' => [
            'field_label' => 'lbl_device_fiber_speed',
            'field_name' => 'device_fiber_speed',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '20',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_firmware' => [
            'field_label' => 'lbl_device_firmware',
            'field_name' => 'device_firmware',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '50',
            'field_type' => 'any',
            'field_validate' => false
        ],
        'device_firmware_update_date' => [
            'field_label' => 'lbl_device_firmware_update_date',
            'field_name' => 'device_firmware_update_date',
            'field_default_val' => '',
            'field_readonly' => false,
            'field_length' => '100',
            'field_type' => 'any',
            'field_validate' => false
        ]
        
    ]
];

?>
