<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Allows editing, viewing and addition of devices. 
*                  Form field components are driven from the lib/form_fields.php file, 
*                  $arr_device_data_format array. It is mandatory that you pre-define form 
*                  fields in $arr_device_data_format and add necessary labels in all used 
*                  language files before applying changes to this module. 
*                  After each change or addition to the devices list, the devices_list, 
*                  templates_list, devices_list_create_dt and templates_list_create_dt sessions 
*                  must be refreshed.
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

$no_js = true;

$err_msg = "";
$arr_devices = [];
$arr_devices_key = [];

if (!isset($_SESSION['devices_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
    $arr_devices_list = json_decode($devices_list_return, true);
    if(count($arr_devices_list) > 0){
        $_SESSION['devices_list'] = $arr_devices_list;
        $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}

$i = 0;
foreach ($_SESSION['devices_list']['item_list'] as $device_data){
    $myarr = $utilities_library->mk_array($device_data['key'],$device_data['property_list']);
    $arr_devices[$i] = $myarr;
    $arr_devices_key[$device_data['key']] = $myarr;
    $i++;
}

# additional sessions we need on this page:
# templates
$arr_templates = [];
$arr_templates_key = [];
if (!isset($_SESSION['templates_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
    $arr_devices_list = json_decode($devices_list_return, true);
    if(count($arr_devices_list) > 0){
        $_SESSION['templates_list'] = $arr_devices_list;
        $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}
$j = 0;
foreach ($_SESSION['templates_list']['item_list'] as $template_data){
    $myarr = $utilities_library->mk_array($template_data['key'],$template_data['property_list']);
    $arr_templates[$j] = $myarr;
    $arr_templates_key[$template_data['key']] = $myarr;
    $j++;
}

# datacenters:
$arr_datacenters = [];
$arr_datacenters_key = [];
if (!isset($_SESSION['datacenters_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $datacenters_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/datacenters',json_encode($comp_id,true));
    $arr_datacenters_list = json_decode($datacenters_list_return, true);
    if(count($arr_datacenters_list) > 0){
        $_SESSION['datacenters_list'] = $arr_datacenters_list;
        $_SESSION['datacenters_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}
$k = 0;
foreach ($_SESSION['datacenters_list']['item_list'] as $datacenter_data){
    $myarr = $utilities_library->mk_array($datacenter_data['key'],$datacenter_data['property_list']);
    $arr_datacenters[$k] = $myarr;
    $arr_datacenters_key[$datacenter_data['key']] = $myarr;
    $k++;
}

// define page number variable
$pg_num = 0;
if (isset($_GET['pg']) && $_GET['pg'] > 0){
    $pg_num = $_GET['pg'];
}

// define did (device id) variable
$did = "";
if (isset($_GET['did']) && strlen($_GET['did']) == 36){
    if(count($arr_devices_key[$_GET['did']]) > 0){
        $did = $_GET['did'];
    }
}

// define tid (template id) variable
$tid = "";
if (isset($_GET['tid']) && strlen($_GET['tid']) == 36){
    if(count($arr_templates_key[$_GET['tid']]) > 0){
        $tid = $_GET['tid'];
    }
}

// define page action variable
$action = "";
$allowed_actions = ['json_download','json','xml_download','add','add_form','save','save_accounts','save_interconnects','save_processes','save_documents','activate','deactivate','add_success','deactivate_success','activate_success','save_success','edit_device','view'];
if (isset($_GET['do']) && in_array($_GET['do'],$allowed_actions)){
    $action = $_GET['do'];
}

// actions

if($action == 'json_download' || $action == 'xml_download'){
    if($action == 'json_download'){
        header("Content-Disposition: attachment; filename=devices.json");
        header('Content-type: application/json');
        print json_encode($arr_devices_key,true);
        exit;
    }else if($action == 'xml_download'){
        $xml1 = xmlrpc_encode($arr_devices_key);
        header("Content-Disposition: attachment; filename=devices.xml");
        header('Content-type: application/json');
        echo $xml1;
        exit;
    }
}

if($action == 'json'){
    $arr_json = [];
    $i = 0;
    foreach ($arr_devices  as $device_data){
        $arr_d = ['id' => $device_data['key'], 'name'=>"".$device_data['device_name']." ".$device_data['device_primary_ip']." ".$device_data['device_addl_ips']." [".$device_data['device_tag']."]"];
        $arr_json[$i] = $arr_d;
        $i = $i + 1;
    }
    header('Cache-Control: no-cache, must-revalidate');
    header('Content-type: application/json');
    print json_encode($arr_json,true);
    exit;
}

if($action == 'add'){

    $err_message = "";
    $form_validation = $utilities_library->template_form_fields_validation($arr_device_data_format['device'],$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
        $action = 'add_form';
        $tid = $_POST['template_id'];
    }else{
        // at least we passed validation; let's check for all textarea fields
        // and convert them to base64
        foreach($_POST as $k=>$v){
            $field_type = $arr_device_data_format['device'][$k]['field_type'];
            if($field_type == 'textarea'){
                $_POST[$k] = base64_encode($v);
            }
        }
        $key = '00000000-0000-000000000-000000000000';
        $tid = '';
        if (isset($_POST['template_id']) && strlen($_POST['template_id']) == 36){
            $tid = $_POST['template_id'];
        }
        if($tid != ''){
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $post_device_data = $utilities_library->mk_json_props_array($key,$_POST,$_POST);
            
            $device_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_device_data,true));
            $arr_device_return = json_decode($device_return,true);

            $err_message = '';
            if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
                $err_message = $arr_device_return['message'];
                $action = 'add_form';
                $tid = $_POST['template_id'];
            }else if($err_message == ''){
                $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
                $rest_client = new rest_client($_SESSION['auth_head'],'');
                $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
                $arr_devices_list = json_decode($devices_list_return, true);
                if(count($arr_devices_list) > 0){
                    $_SESSION['devices_list'] = $arr_devices_list;
                    $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
                }else{
                    $err_msg = "";
                }
                header("location: ".CURRENT_PAGE."?do=add_success");
            }else{
                $action = 'add_form';
                $tid = $_POST['template_id'];
            }
        }else{
            $err_message .= $formatting_library->make_lang_label($arr_labels, 'lbl_err_no_tid', DEFAULT_LANG);
        }

    }   
}


if($action == 'save'){

    $err_message = "";
    $form_validation = $utilities_library->template_form_fields_validation($arr_device_data_format['device'],$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
        $action = 'edit_device';
    }else{
        // at least we passed validation; let's check for all textarea fields
        // and convert them to base64
        foreach($_POST as $k=>$v){
            $field_type = $arr_device_data_format['device'][$k]['field_type'];
            if($field_type == 'textarea'){
                $_POST[$k] = base64_encode($v);
            }
        }
        $key = $did;
        if (isset($arr_devices_key[$did]['device_name'])){
            $arr_old_device_data = $arr_devices_key[$did];
            $tid = $arr_old_device_data['template_id'];
        }
        
        // we are not allowed to change template id
        $_POST['template_id'] = $tid;

        if($did != ''){
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $post_device_data = $utilities_library->mk_json_props_array($did,$_POST,$_POST);
            
            $device_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_device_data,true));
            $arr_device_return = json_decode($device_return,true);

            $err_message = '';
            if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
                $err_message = $arr_device_return['message'];
                $action = 'edit_device';
                $tid = $_POST['template_id'];
            }else if($err_message == ''){
                $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
                $rest_client = new rest_client($_SESSION['auth_head'],'');
                $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
                $arr_devices_list = json_decode($devices_list_return, true);
                if(count($arr_devices_list) > 0){
                    $_SESSION['devices_list'] = $arr_devices_list;
                    $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
                }else{
                    $err_msg = "";
                }
                header("location: ".CURRENT_PAGE."?do=save_success");
            }else{
                $action = 'add_form';
                $tid = $_POST['template_id'];
            }
        }else{
            $err_message .= $formatting_library->make_lang_label($arr_labels, 'lbl_err_no_did', DEFAULT_LANG);
        }

    }   
}

if($action == 'save_accounts'){
    
    $err_message = '';
    if($did != ''){
        // collect device data for web service
        
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $arr_dev = $arr_devices_key[$did];
        
        // remove old accounts 
        for ($x=0; $x<=$arr_dev['accounts_count']; $x++){
            unset($arr_dev["devacct_account_".$x.""]);
            unset($arr_dev["devacct_account_type_".$x.""]);
            unset($arr_dev["devacct_account_pwd_".$x.""]);
            unset($arr_dev["devacct_account_key_".$x.""]);
        }
        
        $i = 0;
        foreach ($_POST['devacct_account'] as $devacct_account){
            
            $devacct_account_type = $_POST['devacct_account_type'][$i];
            $devacct_account_pwd = $_POST['devacct_account_pwd'][$i];
            $devacct_account_key = $_POST['devacct_account_key'][$i];
            $devacct_account_key_pwd = $_POST['devacct_account_key_pwd'][$i];
            if(
                isset($devacct_account) && $devacct_account != '' &&
                isset($devacct_account_type) && $devacct_account_type != '' &&
                isset($devacct_account_pwd) && $devacct_account_pwd != '' &&
                isset($devacct_account_key) && $devacct_account_key != '' 
            ){

                //check if the key password matches
                $pw_stat = 'new';
                $kpw_list = $enc_library->arr_crypto_keys;
                $kpw = $kpw_list[$devacct_account_key]['key_pass'];
                
                    # first; do we have a password?
                    if (isset($devacct_account_pwd) && $devacct_account_pwd != ''){
                        # try to decrypt the password
                        $clear_pw = $enc_library->dec_pwd($devacct_account_pwd, $kpw_list[$devacct_account_key]['key_pass'], $kpw_list[$devacct_account_key]['key_value']);
                        if (isset($clear_pw) && $clear_pw != ''){
                            // we are using the old password
                            $pw_stat = 'old';
                            $devacct_account_pwd_enc = $enc_library->enc_pwd($clear_pw, $devacct_account_key_pwd, $kpw_list[$devacct_account_key]['key_value']);
                        }else{
                            // we got a new password
                            $devacct_account_pwd_enc = $enc_library->enc_pwd($devacct_account_pwd, $devacct_account_key_pwd, $kpw_list[$devacct_account_key]['key_value']);
                        }
                    }else{
                        // password is blank
                    }
                if ($pw_stat == 'new'){
                    if($devacct_account_key_pwd == $kpw){
                        $arr_dev["devacct_account_".$i.""] = $devacct_account;
                        $arr_dev["devacct_account_type_".$i.""] = $devacct_account_type;
                        $devacct_account_pwd_enc = $enc_library->enc_pwd($devacct_account_pwd, $devacct_account_key_pwd, $kpw_list[$devacct_account_key]['key_value']);
                        $arr_dev["devacct_account_pwd_".$i.""] = $devacct_account_pwd_enc;
                        $arr_dev["devacct_account_key_".$i.""] = $devacct_account_key;
                        $i++;
                    }else{
                        $err_message = "Invalid key password for ".$devacct_account."";
                    }
                }else{
                    $arr_dev["devacct_account_".$i.""] = $devacct_account;
                    $arr_dev["devacct_account_type_".$i.""] = $devacct_account_type;
                    $arr_dev["devacct_account_pwd_".$i.""] = $devacct_account_pwd;
                    $arr_dev["devacct_account_key_".$i.""] = $devacct_account_key;
                    $i++;
                }

            }
        }
        $arr_dev['accounts_count'] = $i;
        
        $post_device_data = $utilities_library->mk_json_props_array($did,$arr_dev,$arr_dev);
        //var_dump($post_device_data);
        //exit;
        
        if($err_message == ''){
            
            $device_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_device_data,true));
            $arr_device_return = json_decode($device_return,true);
            if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
                $err_message = $arr_device_return['message'];
                $action = 'edit_device';
                $arr_devices_key[$did] = $arr_dev;
            }else{
                $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
                $rest_client = new rest_client($_SESSION['auth_head'],'');
                $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
                $arr_devices_list = json_decode($devices_list_return, true);
                if(count($arr_devices_list) > 0){
                    $_SESSION['devices_list'] = $arr_devices_list;
                    $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
                }else{
                    $err_msg = "";
                }
                header("location: ".CURRENT_PAGE."?do=save_success");
            }
            
        }else{
            $arr_devices_key[$did] = $arr_dev;
        }
        
    }else{
        $err_message .= $formatting_library->make_lang_label($arr_labels, 'lbl_err_no_did', DEFAULT_LANG);
    }
    
}


if($action == 'save_documents'){
    
    // get a list of files for the current device
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $filegroup = [
        'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
        'file_class' => 'DEVICE',
        'class_id' => $did
    ];
    $arr_files_list = [];
    $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
    $arr_files_list = json_decode($files_list_return, true);
    
    $i = 0;
    $j = 0;
    $k = 0;
    $l = 0;
    
    print "<pre>";
    $arr_existing_files = [];
    $k_arr_existing_files = [];
    $arr_new_files = [];
    $arr_untouched_existing_files = [];
    $arr_untouched_existing_files2 = [];
    $k_arr_untouched_existing_files = [];
    foreach ($_POST['devfile_file_id'] as $file_id){
        
        $file_error = 0;
        $file_size = 0;
        
        $file_class = 'DEVICE';
        $file_class_id = $did;
        $file_name = $_FILES['devfile_file']['name'][$i];
        $file_type = $_FILES['devfile_file']['type'][$i];
        $file_tmp_name = $_FILES['devfile_file']['tmp_name'][$i];
        $file_error = $_FILES['devfile_file']['error'][$i];
        $file_size = $_FILES['devfile_file']['size'][$i];
        $file_details = $_POST['devfile_details'][$i];
        $file_data = base64_encode(file_get_contents($file_tmp_name));
        
        $arr_file['file_id'] = $file_id;
        $arr_file['created_by'] = '';
        $arr_file['created_on'] = '';
        $arr_file['modified_by'] = $_SESSION['user_data']['key'];
        $arr_file['modified_on'] = '';
        $arr_file['class_id'] = $did;
        $arr_file['file_type'] = $file_type;
        $arr_file['file_size'] = $file_size;
        $arr_file['company_id'] = $_SESSION['auth_head']['auth_head_company_id'];
        $arr_file['file_data'] = $file_data;
        $arr_file['file_description'] = $file_details;
        $arr_file['file_item'] = $file_name;
        $arr_file['file_checksum'] = '';
        $arr_file['file_name'] = $file_name;
        $arr_file['file_class'] = 'DEVICE';
        
        
        if($file_id == '') {
            # new files
            $arr_new_files[$j] = $arr_file;
            $j++;
        }else if($file_size > 0 && $file_id != '') {
            #updating existing file
            $arr_existing_files[$k] = $arr_file;
            $k_arr_existing_files[$file_id] = $arr_file;
            $k++;
        }else if($file_size == 0 && $file_id != '') {
            #leaving file as is
            
            $arr_file2['file_id'] = $file_id;
            $arr_file2['file_description'] = $file_details;
            
            $arr_untouched_existing_files[$l] = $arr_file2;
            $k_arr_untouched_existing_files[$file_id] = $arr_file2;
            $l++;
        }

        $i++;
    }
    
    # get the list of current documents
    $filegroup = [
    'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
    'file_class' => 'DEVICE',
    'class_id' => $did
    ];
    $arr_files_list = [];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
    $arr_files_list = json_decode($files_list_return, true);
    
    $files_arr = [];
    $m = 0;
    foreach ($arr_files_list['item_list'] as $f_data){
        
        $file_id = [
        'file_id' => $f_data['key']
        ];
        if($k_arr_existing_files[$f_data['key']]['file_id'] == $f_data['key'] || $k_arr_untouched_existing_files[$f_data['key']]['file_id'] == $f_data['key']) {
            if($k_arr_untouched_existing_files[$f_data['key']]['file_id'] == $f_data['key']){
                // we collect information about the existing file
                $file_info = $utilities_library->mk_array($f_data['key'],$f_data['property_list']);
                
                $arr_file['file_id'] = $file_info['key'];
                $arr_file['created_by'] = $file_info['created_by'];
                $arr_file['created_on'] = $file_info['created_on'];
                $arr_file['modified_by'] = $_SESSION['user_data']['key'];
                $arr_file['modified_on'] = '';
                $arr_file['class_id'] = $did;
                $arr_file['file_type'] = $file_info['file_type'];
                $arr_file['file_size'] = $file_info['file_size'];
                $arr_file['company_id'] = $_SESSION['auth_head']['auth_head_company_id'];
                $arr_file['file_description'] = $k_arr_untouched_existing_files[$f_data['key']]['file_description'];
                $arr_file['file_item'] = $file_info['file_item'];
                $arr_file['file_checksum'] = $file_info['file_checksum'];
                $arr_file['file_name'] = $file_info['file_name'];
                $arr_file['file_class'] = 'DEVICE';
                
                $arr_untouched_existing_files2[$m] = $arr_file;
                $m++;
            }
        }else{
            // we remove documents no longer needed
            $rest_client->delete(WEB_SERVICE_ADDRESS.'/files',json_encode($file_id,true));
        }

    }
    
    // we upload any new documents
    foreach($arr_new_files as $arr_new_file_data){
        $post_file_data = $utilities_library->mk_json_props_array('',$arr_new_file_data,$arr_new_file_data);
        // upload data
        $file_upload = $rest_client->put(WEB_SERVICE_ADDRESS.'/files',json_encode($post_file_data,true));
        $arr_file_upload = json_decode($file_upload,true);
    }
    // we update any existing documents that now have a new file
    foreach($arr_existing_files as $arr_new_file_data){
        $post_file_data = $utilities_library->mk_json_props_array($arr_new_file_data['file_id'],$arr_new_file_data,$arr_new_file_data);
        // upload data
        $file_upload = $rest_client->put(WEB_SERVICE_ADDRESS.'/files',json_encode($post_file_data,true));
        $arr_file_upload = json_decode($file_upload,true);
    }
    // we update the details for existing documents
    // that don't have a new file
    foreach($arr_untouched_existing_files2 as $arr_new_file_data){
        $post_file_data = $utilities_library->mk_json_props_array($arr_new_file_data['file_id'],$arr_new_file_data,$arr_new_file_data);
        // upload data
        $file_upload = $rest_client->put(WEB_SERVICE_ADDRESS.'/files',json_encode($post_file_data,true));
        $arr_file_upload = json_decode($file_upload,true);
    }
    
    header("location: ".CURRENT_PAGE."?do=save_success");
}


if($action == 'save_interconnects'){

    $err_message = '';
    if($did != ''){
        // collect device data for web service
    
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $arr_ic = $arr_devices_key[$did];
    
        // remove old interconnects
        for ($x=0; $x<=$arr_ic['interconnects_count']; $x++){
            unset($arr_ic["devic_to_".$x.""]);
            unset($arr_ic["devic_protocol_".$x.""]);
            unset($arr_ic["devic_port_".$x.""]);
            unset($arr_ic["devic_notes_".$x.""]);
        }

        $i = 0;
        foreach ($_POST['devic_to'] as $devic_to){
    
            $devic_protocol = $_POST['devic_protocol'][$i];
            $devic_port = $_POST['devic_port'][$i];
            $devic_notes = $_POST['devic_notes'][$i];
            if(
                    isset($devic_to) && $devic_to != '' &&
                    isset($devic_protocol) && $devic_protocol != '' &&
                    isset($devic_port) && $devic_port != '' &&
                    isset($devic_notes) && $devic_notes != ''
            ){
                $arr_ic["devic_to_".$i.""] = $devic_to;
                $arr_ic["devic_protocol_".$i.""] = $devic_protocol;
                $arr_ic["devic_port_".$i.""] = $devic_port;
                $arr_ic["devic_notes_".$i.""] = base64_encode($devic_notes);
                $i++;
            }
    
        }
    
        $arr_ic['interconnects_count'] = $i;
    
        $post_ic_data = $utilities_library->mk_json_props_array($did,$arr_ic,$arr_ic);
        $device_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_ic_data,true));
        $arr_device_return = json_decode($device_return,true);

        if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
            $err_message = $arr_device_return['message'];
            $action = 'edit_device';
            $arr_devices_key[$did] = $arr_ic;
        }else{
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
            $arr_devices_list = json_decode($devices_list_return, true);
            if(count($arr_devices_list) > 0){
                $_SESSION['devices_list'] = $arr_devices_list;
                $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
            header("location: ".CURRENT_PAGE."?do=save_success");
        }
    
    }else{
        $err_message .= $formatting_library->make_lang_label($arr_labels, 'lbl_err_no_did', DEFAULT_LANG);
    }
    

    header("location: ".CURRENT_PAGE."?do=save_success");
}

if($action == 'save_processes'){
    
    $err_message = '';
    if($did != ''){
        // collect device data for web service
    
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $arr_procs = $arr_devices_key[$did];
    
        // remove old processes
        for ($x=0; $x<=$arr_procs['processes_count']; $x++){
            unset($arr_procs["devproc_acct_".$x.""]);
            unset($arr_procs["devproc_path_".$x.""]);
            unset($arr_procs["devproc_schedule_".$x.""]);
            unset($arr_procs["devproc_notes_".$x.""]);
        }
    
        $i = 0;
        foreach ($_POST['devproc_path'] as $devproc_path){
    
            $devproc_acct = $_POST['devproc_acct'][$i];
            //$devproc_path = $_POST['devproc_path'][$i];
            $devproc_schedule = $_POST['devproc_schedule'][$i];
            $devproc_notes = $_POST['devproc_notes'][$i];
            if(
                isset($devproc_acct) && $devproc_acct != '' &&
                isset($devproc_path) && $devproc_path != '' &&
                isset($devproc_schedule) && $devproc_schedule != '' &&
                isset($devproc_notes) && $devproc_notes != ''
            ){
    
                $arr_procs["devproc_acct_".$i.""] = $devproc_acct;
                $arr_procs["devproc_path_".$i.""] = $devproc_path;
                $arr_procs["devproc_schedule_".$i.""] = $devproc_schedule;
                $arr_procs["devproc_notes_".$i.""] = base64_encode($devproc_notes);
                $i++;
            }
    
        }

        $arr_procs['processes_count'] = $i;
    
        $post_procs_data = $utilities_library->mk_json_props_array($did,$arr_procs,$arr_procs);
    
        $device_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_procs_data,true));
        $arr_device_return = json_decode($device_return,true);
        if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
            $err_message = $arr_device_return['message'];
            $action = 'edit_device';
            $arr_devices_key[$did] = $arr_procs;
        }else{
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
            $arr_devices_list = json_decode($devices_list_return, true);
            if(count($arr_devices_list) > 0){
                $_SESSION['devices_list'] = $arr_devices_list;
                $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
            header("location: ".CURRENT_PAGE."?do=save_success");
        }
    
    }else{
        $err_message .= $formatting_library->make_lang_label($arr_labels, 'lbl_err_no_did', DEFAULT_LANG);
    }

}


if($action == 'deactivate' || $action == 'activate'){
    // do we have a device_id?
    if($did != ''){
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $post_device_data = ['device_id' => $did];

        // submit to app server
        $device_return = $rest_client->delete(WEB_SERVICE_ADDRESS.'/devices',json_encode($post_device_data,true));
        $arr_device_return = json_decode($device_return,true);
        // check for final errors
        if (str_replace(' ','',$arr_device_return['message']) != '' && $arr_device_return['status'] > 300 && $arr_device_return['status'] < 600) {
            $err_message = $arr_device_return['message'];
        }else{
            // no errors; we re-generate the users list session and
            // redirect to nice success page
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $device_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/devices',json_encode($comp_id,true));
            $arr_devices_list = json_decode($device_list_return, true);
            if(count($arr_devices_list) > 0){
                $_SESSION['devices_list'] = $arr_devices_list;
                $_SESSION['devices_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }

            if($action == 'activate'){
                header("location: ".CURRENT_PAGE."?do=activate_success&pg=".$pg_num."&did=".$did."");
            }else{
                header("location: ".CURRENT_PAGE."?do=deactivate_success&pg=".$pg_num."&did=".$did."");
            }
        }
    }
}


require_once(WEB_ROOT.'/incl/top.php');

?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">

    <h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_devices_mg_head', DEFAULT_LANG); ?></h2>

    <div class="row">
        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
        
        <div class="btn-group">
          <button type="button" class="btn btn-primary dropdown-toggle" data-toggle="dropdown">
            <?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_device', DEFAULT_LANG); ?> <span class="caret"></span>
          </button>
          <ul class="dropdown-menu" role="menu">
          <?php 
            $templates_list = $utilities_library->select_templates_ds(false,false);
            foreach($templates_list as $k=>$v){
                print "<li><a href=\"".CURRENT_PAGE."?do=add_form&tid=".$k."\">".$v."</a></li>";
            }
          ?>
          </ul>
        </div>
        
        <div class="btn-group">
          <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
            <?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_download', DEFAULT_LANG); ?> <span class="caret"></span>
          </button>
          <ul class="dropdown-menu" role="menu">
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=xml_download">XML</a></li>
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=json_download">JSON</a></li>
          </ul>
        </div>
    </div>
    <br />
    
<?php if ($action != 'edit_device'){ ?>
<!-- begin search section -->

<form class="form-horizontal" role="form" name="dev_srch_form" id="dev_srch_form" action="<?php echo CURRENT_PAGE; ?>" method="get">
<div class="form-group">
<label for="d_srch" class="col-lg-2 control-label"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></label>
<div class="col-lg-6">
    <input
        type="text" 
        id="user-input" 
        class="form-control typeahead"
        placeholder="<?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search_dev_field', DEFAULT_LANG); ?>"
        autocomplete="off"
        data-provide="typeahead"
    />
    </div>
    
<input type="hidden" name="did" id="did" value="" /><button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></button>
</div>
</form>
    <script src="js/jquery-1.9.1.min.js"></script>
    <script src="js/bootstrap.min2.js"></script>
    <script src="js/underscore-min.js"></script>

    <script type="text/javascript">

    $(function(){
        //var devObjs = {};
        var devNames = [];
        $(".typeahead").typeahead({
            source: function ( query, process ) {
                $.ajax({
                    url: '<?php echo CURRENT_PAGE; ?>?do=json'
                    ,cache: false
                    ,success: function(data){
                        devObjs = {};
                        devNames = [];
                        _.each( data, function(item, ix, list){
                            devNames.push( item.name );
                            devObjs[ item.name ] = item.id;
                        });
                        process( devNames );
                    }
                });
            }
            , items: 15
            , updater: function ( selectedName ) {
                $( "#did" ).val( devObjs[ selectedName ] );
                return selectedName;
            }
        });
    });

    </script>

<br />
<!-- end search section -->
<?php } ?>

    <!-- begin alert options -->
    <?php
        if($err_message != ''){
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
        }
        if($action == 'add_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_add_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'deactivate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_deactivate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'activate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_activate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'save_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_save_success', DEFAULT_LANG)."</div>";
        }

    ?>
    <!-- end alert options -->
    
<?php

if ($action == 'add_form'){
    // we show the XHTML form to add a device
    // for the selected template
    // get template_data
    if ($tid != ''){
        $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id'],'template_id' => $tid];
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $template_data_return = $rest_client->get(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
        $template_data = json_decode($template_data_return, true);
        if(count($template_data) > 0){
            $template_info = $utilities_library->mk_array($template_data['key'],$template_data['property_list']);
        }else{
            $err_msg = "";
        }
        $obj_data = [];
        if (count($err_message) > 0){
            $obj_data = $_POST;
        }
        if(isset($template_info['template_code']) && $template_info['template_code'] !=''){
            $xhtml_data = $formatting_library->cmdbxsl_to_xhtml(base64_decode($template_info['template_code']),$arr_labels,DEFAULT_LANG, $arr_device_data_format['device'],$obj_data,'edit');
            print "<form action=\"".CURRENT_PAGE."?do=add\" method=\"post\"><input type=\"hidden\" name=\"template_id\" value=\"".$tid."\">";
            print $xhtml_data;
            print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_device', DEFAULT_LANG)."</button>";
            print "</form>";
            print "<ul class=\"pagination pagination-sm\">";
            print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
            print "</ul>";
        }else{
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$formatting_library->make_lang_label($arr_labels, 'lbl_err_no_such_template', DEFAULT_LANG)."</div>";
        }
    }
}

$table_hide_actions = ['add_device','edit_device','add_form','view'];
if (!in_array($action, $table_hide_actions)){
    # display the devices table
    if (count($arr_devices ) > 0) {
?>

<!-- display devices list table -->

<table class="table table-striped">
<tr>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_device_name', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_device_domain', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_device_dc', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_device_type', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_last_modified', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_status', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_action', DEFAULT_LANG); ?></th>
</tr>
<?php 
// check if pagination is needed

$start_rec = $pg_num * MAX_RECS_PER_PAGE;
$end_rec = $start_rec + MAX_RECS_PER_PAGE;

$no_paging = false;
if($did != ''){
    $arr_d_search = [];
    $arr_d_search[0] = $arr_devices_key[$did];
    if(count($arr_d_search) > 0){
        $arr_devices = $arr_d_search;
        $no_paging = true;
    }
}

if(count($arr_devices) <= MAX_RECS_PER_PAGE){
    $no_paging = true;
}else if($start_rec > count($arr_devices)){
    $start_rec = 0;
    $end_rec = $start_rec + MAX_RECS_PER_PAGE;
    $pg_num = 0;
}

print $utilities_library->make_devices_table($arr_devices, DEFAULT_LANG, CURRENT_PAGE, $start_rec, $end_rec, $arr_labels, $arr_device_data_format, $pg_num, $arr_datacenters_key, $arr_templates_key);

?>

</table>
<!-- end display templates list table -->

<!-- begin pagination section -->
<?php 

if($no_paging == false && $action != 'edit_device'){
    print $utilities_library->make_pagination(count($arr_devices),$pg_num,CURRENT_PAGE,$arr_labels);
}else if($did != '' || $action == 'edit_device'){
    print "<ul class=\"pagination pagination-sm\">";
    print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
    print "</ul>";
}
?>
<!-- end pagination section -->


<?php 
    }
    
}
?>

<!-- begin edit device section -->
<?php 
if ($action == 'edit_device'){
    
    $device_data = $arr_devices_key[$did];

    if(!isset($device_data) || $device_data == null || $device_data['key'] != $did){
        print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$formatting_library->make_lang_label($arr_labels, 'lbl_device_not_found', DEFAULT_LANG)."</div>";
    }else{
    
        $no_js = false;
        
    print "<h2>".$device_data['device_name'].".".$device_data['device_domain']."</h2>";
        print "<div class=\"panel-group\" id=\"accordion\">";
        
        print "<div class=\"panel panel-default\">";
        print "<div class=\"panel-heading\">";
        print "<h4 class=\"panel-title\">";
        print "<a data-toggle=\"collapse\" data-parent=\"#accordion\" href=\"#collapseInfo\">";
        print $formatting_library->make_lang_label($arr_labels, 'lbl_device_info', DEFAULT_LANG);
        print "</a>";
        print "</h4>";
        print "</div>";
        print "<div id=\"collapseInfo\" class=\"panel-collapse collapse in\">";
        print "<div class=\"panel-body\">";
        print "<div class=\"row\">";
        print "<div class=\"col-lg-12\">";
        
        $tc = $arr_templates_key[$device_data['template_id']]['template_code'];
        $xhtml_data = $formatting_library->cmdbxsl_to_xhtml(base64_decode($tc),$arr_labels,DEFAULT_LANG, $arr_device_data_format['device'],$device_data,'edit');
        print "<form action=\"".CURRENT_PAGE."?do=save&did=".$did."\" method=\"post\">";
        print "<br />".$xhtml_data;
        print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_btn_save_device', DEFAULT_LANG)."</button>";
        print "</form>";
    
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        
        print "<div class=\"panel panel-default\">";
        print "<div class=\"panel-heading\">";
        print "<h4 class=\"panel-title\">";
        print "<a data-toggle=\"collapse\" data-parent=\"#accordion\" href=\"#collapseInterconnects\">";
        print $formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnects', DEFAULT_LANG);
        print "</a>";
        print "</h4>";
        print "</div>";
        print "<div id=\"collapseInterconnects\" class=\"panel-collapse collapse\">";
        print "<div class=\"panel-body\">";
        print "<div class=\"row\">";
        print "<div class=\"col-lg-12\">";
        
        print "<form action=\"".CURRENT_PAGE."?do=save_interconnects&did=".$did."\" method=\"post\">";
        print "<input type=\"button\" class=\"btn btn-success btn-group-sm\" id=\"newICbutton\" onclick=\"insICRow('devic_table_tb')\" value=\"".$formatting_library->make_lang_label($arr_labels, 'lbl_device_add_interconnect', $lang)."\" />";
        print "<table id=\"devic_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_to', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_protocol', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_port', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_notes', DEFAULT_LANG)."</th>";
        print "<th></th>";
        print "</tr>";
        
        print $utilities_library->make_devices_interconnects_table($device_data,$arr_devices_key,$arr_labels,'edit');
        print "</table>";
        print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_save_interconnect', DEFAULT_LANG)."</button>";
        print "</form>";
        
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        
        print "<div class=\"panel panel-default\">";
        print "<div class=\"panel-heading\">";
        print "<h4 class=\"panel-title\">";
        print "<a data-toggle=\"collapse\" data-parent=\"#accordion\" href=\"#collapseProcesses\">";
        print $formatting_library->make_lang_label($arr_labels, 'lbl_device_processes', DEFAULT_LANG);
        print "</a>";
        print "</h4>";
        print "</div>";
        print "<div id=\"collapseProcesses\" class=\"panel-collapse collapse\">";
        print "<div class=\"panel-body\">";
        print "<div class=\"row\">";
        print "<div class=\"col-lg-12\">";
        
        print "<form action=\"".CURRENT_PAGE."?do=save_processes&did=".$did."\" method=\"post\">";
        print "<input type=\"button\" class=\"btn btn-success btn-group-sm\" id=\"newProcbutton\" onclick=\"insProcRow('devproc_table_tb')\" value=\"".$formatting_library->make_lang_label($arr_labels, 'lbl_device_add_process', $lang)."\" />";
        print "<table id=\"devproc_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_account', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_path', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_schedule', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_notes', DEFAULT_LANG)."</th>";
        print "<th></th>";
        print "</tr>";
        
        print $utilities_library->make_devices_processes_table($device_data,$arr_labels,'edit');
        print "</table>";
        print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_save_process', DEFAULT_LANG)."</button>";
        print "</form>";
        
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        
        print "<div class=\"panel panel-default\">";
        print "<div class=\"panel-heading\">";
        print "<h4 class=\"panel-title\">";
        print "<a data-toggle=\"collapse\" data-parent=\"#accordion\" href=\"#collapseAccounts\">";
        print $formatting_library->make_lang_label($arr_labels, 'lbl_device_accounts', DEFAULT_LANG);
        print "</a>";
        print "</h4>";
        print "</div>";
        print "<div id=\"collapseAccounts\" class=\"panel-collapse collapse\">";
        print "<div class=\"panel-body\">";
        print "<div class=\"row\">";
        print "<div class=\"col-lg-12\">";

        print "<form action=\"".CURRENT_PAGE."?do=save_accounts&did=".$did."\" method=\"post\">";
        print "<input type=\"button\" class=\"btn btn-success btn-group-sm\" id=\"newAcctbutton\" onclick=\"insAcctRow('devacct_table_tb')\" value=\"".$formatting_library->make_lang_label($arr_labels, 'lbl_device_add_account', $lang)."\" />";
        print "<table id=\"devacct_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_type', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_password', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_enc_key', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_enc_key_password', DEFAULT_LANG)."</th>";
        print "<th></th>";
        print "</tr>";
        print $utilities_library->make_devices_accounts_table($device_data,$enc_library->arr_crypto_keys,$arr_labels,'edit');
        print "</table>";
        print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_save_accounts', DEFAULT_LANG)."</button>";
        print "</form>";
        
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        
        print "<div class=\"panel panel-default\">";
        print "<div class=\"panel-heading\">";
        print "<h4 class=\"panel-title\">";
        print "<a data-toggle=\"collapse\" data-parent=\"#accordion\" href=\"#collapseDocuments\">";
        print $formatting_library->make_lang_label($arr_labels, 'lbl_device_documents', DEFAULT_LANG);
        print "</a>";
        print "</h4>";
        print "</div>";
        print "<div id=\"collapseDocuments\" class=\"panel-collapse collapse\">";
        print "<div class=\"panel-body\">";
        print "<div class=\"row\">";
        print "<div class=\"col-lg-12\">";
        
        print "<form action=\"".CURRENT_PAGE."?do=save_documents&did=".$did."\" method=\"post\" enctype=\"multipart/form-data\">";
        print "<input type=\"button\" class=\"btn btn-success btn-group-sm\" id=\"newDocbutton\" onclick=\"insDocRow('devdoc_table_tb')\" value=\"".$formatting_library->make_lang_label($arr_labels, 'lbl_device_add_document', $lang)."\" />";
        print "<table id=\"devdoc_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_name', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_details', DEFAULT_LANG)."</th>";
        print "<th></th>";
        print "</tr>";
        
        $filegroup = [
        'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
        'file_class' => 'DEVICE',
        'class_id' => $did
        ];
        $arr_files_list = [];
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
        $arr_files_list = json_decode($files_list_return, true);
        
        $files_arr = [];
        foreach ($arr_files_list['item_list'] as $f_data){
            $myarr = $utilities_library->mk_array($f_data['key'],$f_data['property_list']);
            $files_arr[$f_data['key']] = $myarr;
        }
        print $utilities_library->make_devices_files_table($device_data,$files_arr,$arr_labels,'edit');
        print "</table>";
        print "<button class=\"btn btn-success\" type=\"submit\">".$formatting_library->make_lang_label($arr_labels, 'lbl_device_save_documents', DEFAULT_LANG)."</button>";
        print "</form>";
        
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        print "</div>";
        
        print "</div>";
    }
    
    print "<ul class=\"pagination pagination-sm\">";
    print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
    print "</ul>";
}

if ($action == 'view'){
    
    $device_data = $arr_devices_key[$did];

    if(!isset($device_data) || $device_data == null || $device_data['key'] != $did){
        print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$formatting_library->make_lang_label($arr_labels, 'lbl_device_not_found', DEFAULT_LANG)."</div>";
    }else{

        print "<div id=\"printable\">";
        print "<h2>".$device_data['device_name'].".".$device_data['device_domain']."</h2>";
        
        print "<div class=\"bs-callout bs-callout-primary\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_info', DEFAULT_LANG)."</h4>";
        $tc = $arr_templates_key[$device_data['template_id']]['template_code'];
        $xhtml_data = $formatting_library->cmdbxsl_to_xhtml(base64_decode($tc),$arr_labels,DEFAULT_LANG, $arr_device_data_format['device'],$device_data,'view');
        print $xhtml_data;
        print "</div>";
        
        print "<div class=\"bs-callout bs-callout-warning\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnects', DEFAULT_LANG)."</h4>";
        print "<table id=\"devic_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_to', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_protocol', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_port', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_interconnect_notes', DEFAULT_LANG)."</th>";
        print "</tr>";
        print $utilities_library->make_devices_interconnects_table($device_data,$arr_devices_key,$arr_labels,'view');
        print "</table>";
        print "<h4><a href=\"#downtimedetailModal".$did."\" data-did=\"".$did."\" data-toggle=\"modal\">".formatting_library::make_lang_label($arr_labels, 'lbl_device_downtime_impact', $lang)."</a></h4>";
        print "</div>";
        
        $html_ret = "<!-- display dc modal section for ID ".$j." -->";
        $html_ret = "<div class=\"modal fade\" id=\"downtimedetailModal".$did."\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myModalLabel\" aria-hidden=\"true\">";
        $html_ret .= "<div class=\"modal-dialog\">";
        $html_ret .= "<div class=\"modal-content\">";
        $html_ret .= "<div class=\"modal-header\">";
        $html_ret .= "<button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-hidden=\"true\">×</button>";
        $html_ret .= "<h3 id=\"myModalLabel\">".formatting_library::make_lang_label($arr_labels, 'lbl_device_downtime_impact', $lang)."</h3><strong>".$device_data['device_name'].".".$device_data['device_domain']."</strong>";
        $html_ret .= "</div>";
        $html_ret .= "<div class=\"modal-body\">";
        $html_ret .= "<div class=\"form-group\">";
        $html_ret .= $utilities_library->make_devices_downtime_impact($device_data,$arr_devices_key,$arr_labels);
        $html_ret .= "</div>";
        
        $html_ret .= "</div>";
        $html_ret .= "</div>";
        $html_ret .= "</div>";
        $html_ret .= "</div>";
        
        print $html_ret;
        
        print "<div class=\"bs-callout bs-callout-info\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_processes', DEFAULT_LANG)."</h4>";
        print "<table id=\"devproc_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_account', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_path', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_schedule', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_process_notes', DEFAULT_LANG)."</th>";
        print "</tr>";
        print $utilities_library->make_devices_processes_table($device_data,$arr_labels,'view');
        print "</table>";
        print "</div>";
        
        print "<div class=\"bs-callout bs-callout-success\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_accounts', DEFAULT_LANG)."</h4>";
        print "<table id=\"devacct_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_type', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_password', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_account_enc_key', DEFAULT_LANG)."</th>";
        print "</tr>";
        print $utilities_library->make_devices_accounts_table($device_data,$enc_library->arr_crypto_keys,$arr_labels,'view');
        print "</table>";
        print "</div>";
    
        print "<div class=\"bs-callout bs-callout-danger\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_documents', DEFAULT_LANG)."</h4>";
        
        print "<table id=\"devdoc_table_tb\" class=\"table table-striped\">";
        print "<tr>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_name', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_type', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_size', DEFAULT_LANG)."</th>";
        print "<th>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_document_details', DEFAULT_LANG)."</th>";
        print "</tr>";
        
        $filegroup = [
        'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
        'file_class' => 'DEVICE',
        'class_id' => $did
        ];
        $arr_files_list = [];
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $files_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/files',json_encode($filegroup,true));
        $arr_files_list = json_decode($files_list_return, true);
        
        $files_arr = [];
        foreach ($arr_files_list['item_list'] as $f_data){
            $myarr = $utilities_library->mk_array($f_data['key'],$f_data['property_list']);
            $files_arr[$f_data['key']] = $myarr;
        }
        print $utilities_library->make_devices_files_table($device_data,$files_arr,$arr_labels,'view');
        print "</table>";
        
        print "</div>";
        
        print "<div class=\"bs-callout bs-callout-primary\">";
        print "<h4>".$formatting_library->make_lang_label($arr_labels, 'lbl_device_tickets', DEFAULT_LANG)."</h4>";
        
        $ticketsgroup = [
        'company_id' => $_SESSION['auth_head']['auth_head_company_id'],
        'device_id' => $did
        ];
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $tickets_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/tickets',json_encode($ticketsgroup,true));
        $arr_tickets_list = json_decode($tickets_list_return, true);
        
        $tickets_arr = [];
        foreach ($arr_tickets_list['item_list'] as $t_data){
            $myarr = $utilities_library->mk_array($t_data['key'],$t_data['property_list']);
            $tickets_arr[$myarr['ticket_number']] = $myarr;
        }
        
        print $utilities_library->make_devices_tickets_table($device_data,$tickets_arr, $arr_labels);
        print "</div>";
        
        print "</div>";
        

        
    }
    
    print "<ul class=\"pagination pagination-sm\">";
    print "<li><a href=\"".CURRENT_PAGE."?pg=0\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
    print "<li><a href=\"".CURRENT_PAGE."?did=".$did."&do=edit_device\">".$formatting_library->make_lang_label($arr_labels,'lbl_edit',DEFAULT_LANG)."</a></li>";
    print "</ul>";
}

?>
<!-- end edit device section -->


<?php 
require_once(WEB_ROOT.'/incl/bottom.php');

?>
