<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Allows editing, viewing and addition of templates. 
*                  Form field components are driven from the lib/form_fields.php 
*                  file, $arr_template_data_format array. It is mandatory that you 
*                  pre-define form fields in $arr_template_data_format and add 
*                  necessary labels in all used language files before applying 
*                  changes to this module. After each change or addition to the 
*                  templates list, the templates_list and templates_list_create_dt 
*                  sessions must be refreshed.
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

if($_SESSION['user_data']['access_level'] != 'ADMIN' && $_SESSION['user_data']['access_level'] != 'MANAGER'){
    header('location: dashboard.php');
}

// define data variables
$err_msg = "";
$arr_templates = [];
$arr_templates_key = [];
if (!isset($_SESSION['templates_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $devices_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
    $arr_devices_list = json_decode($devices_list_return, true);
    if(count($arr_devices_list) > 0){
        $_SESSION['templates_list'] = $arr_devices_list;
        $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
}
$i = 0;
foreach ($_SESSION['templates_list']['item_list'] as $template_data){
    $myarr = $utilities_library->mk_array($template_data['key'],$template_data['property_list']);
    $arr_templates[$i] = $myarr;
    $arr_templates_key[$template_data['key']] = $myarr;
    $i++;
}

// define page number variable
$pg_num = 0;
if (isset($_GET['pg']) && $_GET['pg'] > 0){
    $pg_num = $_GET['pg'];
}

// define tid (template id) variable
$tid = "";
if (isset($_GET['tid']) && strlen($_GET['tid']) == 36){
    $tid = $_GET['tid'];
}

// define page action variable
$action = "";
if (isset($_GET['do']) && ($_GET['do'] == 'json_download' || $_GET['do'] == 'xml_download' || $_GET['do'] == 'add' || $_GET['do'] == 'save' || $_GET['do'] == 'activate' || $_GET['do'] == 'deactivate' || $_GET['do'] == 'add_success' || $_GET['do'] == 'deactivate_success' || $_GET['do'] == 'activate_success' || $_GET['do'] == 'save_success')){
    $action = $_GET['do'];
}

// actions

if($action == 'json_download' || $action == 'xml_download'){
    if($action == 'json_download'){
        header("Content-Disposition: attachment; filename=templates.json");
        header('Content-type: application/json');
        print json_encode($arr_templates_key,true);
        exit;
    }else if($action == 'xml_download'){
        $xml1 = xmlrpc_encode($arr_templates_key);
        header("Content-Disposition: attachment; filename=templates.xml");
        header('Content-type: application/json');
        echo $xml1;
        exit;
    }
}

if($action == 'deactivate' || $action == 'activate'){
    // do we have a template_id?
    if($tid != ''){
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $post_template_data = ['template_id' => $tid];

        // submit to app server
        $template_return = $rest_client->delete(WEB_SERVICE_ADDRESS.'/templates',json_encode($post_template_data,true));
        $arr_template_return = json_decode($template_return,true);
        // check for final errors
        if (str_replace(' ','',$arr_template_return['message']) != '' && $arr_template_return['status'] > 300 && $arr_template_return['status'] < 600) {
            $err_message = $arr_template_return['message'];
        }else{
            // no errors; we re-generate the users list session and
            // redirect to nice success page
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $dc_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
            $arr_dc_list = json_decode($dc_list_return, true);
            if(count($arr_dc_list) > 0){
                $_SESSION['templates_list'] = $arr_dc_list;
                $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }

            if($_GET['do'] == 'activate'){
                header("location: ".CURRENT_PAGE."?do=activate_success&pg=".$pg_num."&tid=".$tid."");
            }else{
                header("location: ".CURRENT_PAGE."?do=deactivate_success&pg=".$pg_num."&tid=".$tid."");
            }
        }
    }
}


if($action == 'add'){
    $err_message = "";
    $form_validation = $utilities_library->form_fields_validation($arr_template_data_format,$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        $_POST['active_yn'] = 'Y';
        // avoid EOL while scanning string literal errors
        foreach ($arr_template_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        $post_template_data = $utilities_library->mk_json_props_array('',$_POST,$_POST);
        
        $template_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/templates',json_encode($post_template_data,true));
        $arr_template_return = json_decode($template_return,true);
        if (str_replace(' ','',$arr_template_return['message']) != '' && $arr_template_return['status'] > 300 && $arr_template_return['status'] < 600) {
            $err_message = $arr_template_return['message'];
        }else{
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $templates_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
            $arr_templates_list = json_decode($templates_list_return, true);
            if(count($arr_templates_list) > 0){
                $_SESSION['templates_list'] = $arr_templates_list;
                $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
            header("location: ".CURRENT_PAGE."?do=add_success");
        }
    }
}


if($action == 'save'){
    $err_message = "";
    $form_validation = $utilities_library->form_fields_validation($arr_template_data_format,$_POST);
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        // avoid EOL while scanning string literal errors
        
        foreach ($arr_template_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }

        $post_template_data = $utilities_library->mk_json_props_array($tid,$_POST,$_POST);

        $template_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/templates',json_encode($post_template_data,true));
        $arr_template_return = json_decode($template_return,true);
        if (str_replace(' ','',$arr_template_return['message']) != '' && $arr_template_return['status'] > 300 && $arr_template_return['status'] < 600) {
            $err_message = $arr_template_return['message'];
        }else{
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $templates_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/templates',json_encode($comp_id,true));
            $arr_templates_list = json_decode($templates_list_return, true);
            if(count($arr_templates_list) > 0){
                $_SESSION['templates_list'] = $arr_templates_list;
                $_SESSION['templates_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }else{
                $err_msg = "";
            }
            header("location: ".CURRENT_PAGE."?do=save_success");
        }
    }
}


require_once(WEB_ROOT.'/incl/top.php');

?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">

        <h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_devices_templates_head', DEFAULT_LANG); ?></h2>

    <div class="row">
        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#new_template" role="button" class="btn btn-primary" data-toggle="modal"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_template', DEFAULT_LANG); ?></a>
        <div class="btn-group">
        <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
            <?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_download', DEFAULT_LANG); ?> <span class="caret"></span>
          </button>
          <ul class="dropdown-menu" role="menu">
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=xml_download">XML</a></li>
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=json_download">JSON</a></li>
          </ul>
        </div>
    </div>
    <br />
    
    <!-- begin alert options -->
    <?php
        if($err_message != ''){
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
        }
        if($action == 'add_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_template_add_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'deactivate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_template_deactivate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'activate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_template_activate_success', DEFAULT_LANG)."</div>";
        }
        if($action == 'save_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_template_save_success', DEFAULT_LANG)."</div>";
        }

    ?>
    <!-- end alert options -->

<!-- display DC list table -->
    
<?php if (count($arr_templates ) > 0) { ?>
<table class="table table-striped">
<tr>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_template_name', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_last_modified', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_status', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_template_preview', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_action', DEFAULT_LANG); ?></th>
</tr>
<?php 
// check if pagination is needed

$start_rec = $pg_num * MAX_RECS_PER_PAGE;
$end_rec = $start_rec + MAX_RECS_PER_PAGE;

$no_paging = false;
if($tid != ''){
    $arr_t_search = [];
    $arr_t_search[0] = $arr_templates_key[$tid];
    if(count($arr_t_search) > 0){
        $arr_templates = $arr_t_search;
        $no_paging = true;
    }
}

if(count($arr_templates) <= MAX_RECS_PER_PAGE){
    $no_paging = true;
}else if($start_rec > count($arr_templates)){
    $start_rec = 0;
    $end_rec = $start_rec + MAX_RECS_PER_PAGE;
    $pg_num = 0;
}

print $utilities_library->make_templates_table($arr_templates, DEFAULT_LANG, CURRENT_PAGE, $start_rec, $end_rec, $arr_labels, $arr_template_data_format, $pg_num);

?>

</table>
<!-- end display DC list table -->

<!-- begin pagination section -->
<?php 
if($no_paging == false && $action != 'edit_template'){
    print $utilities_library->make_pagination(count($arr_templates),$pg_num,CURRENT_PAGE,$arr_labels);
}else if($tid != '' || $action == 'edit_template'){
    print "<ul class=\"pagination pagination-sm\">";
    print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
    print "</ul>";
}
?>
<!-- end pagination section -->

<?php } ?>

<!-- display add dc section -->

<form action="<?php echo CURRENT_PAGE; ?>?do=add" method="post">

<div class="modal fade" id="new_template" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
<div class="modal-dialog">
<div class="modal-content">

<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
<h3 id="myModalLabel"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_new_template', DEFAULT_LANG); ?></h3>
</div>
<div class="modal-body">
<?php 
if($err_message != ''){
    print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
}

print "<div class=\"span4\">";
print $formatting_library->make_form($arr_labels, $arr_template_data_format['info'], DEFAULT_LANG, null, $_POST, $form_validation);
print "</div>";

?>


</div> <!-- end modal body -->

<div class="modal-footer">
<button class="btn btn-danger" data-dismiss="modal" aria-hidden="true"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_cancel', DEFAULT_LANG); ?></button>
<button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_template', DEFAULT_LANG); ?></button>
</div> <!-- end modal footer -->

</div> <!-- end modal content -->
</div> <!-- end modal dialog -->
</div> <!-- end modal fade -->
</form>
    
    
<?php

require_once(WEB_ROOT.'/incl/bottom.php');

?>
