<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Provide ability to change their contact information, password and 
*                  locale details. Keep in mind that the user account (username) should never 
*                  be a editable field as accounts are being setup by managers and administrators 
*                  and must be unique for the entire organization. Form field components are 
*                  driven from the lib/form_fields.php file, $arr_user_data_format array 
*                  (same as the users module). It is mandatory that you pre-define form 
*                  fields in $arr_user_data_format and add necessary labels in all used 
*                  language files before applying changes to this module. 
*                  As soon as the profile is changed, you must also update sessions:
* 
*                  auth_head - Header authentication session for all REST requests
*                  user_data - User information session
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

if($_GET['do'] == 'save'){
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $err_message = "";
    // form field validation
    $form_validation = $utilities_library->form_fields_validation($arr_user_data_format,$_POST);

    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        // make array with all required components  
        $post_usr_data = $utilities_library->mk_json_props_array($_SESSION['user_data']['key'],$_SESSION['user_data'],$_POST);
        
        // submit to app server
        $user_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/user',json_encode($post_usr_data,true));
        // check for final errors
        if ((str_replace(' ','',$user_return['message']) != '' && $user_return['status'] > 300 && $user_return['status'] < 600) || (str_replace(' ','',$arr_co_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
            $err_message = $user_return['message'];
        }else{
            $arr_usr_return = json_decode($user_return, true);
            // re-create the user session
            $_SESSION['user_data'] = $utilities_library->mk_array($arr_usr_return['key'],$arr_usr_return['property_list']);
            // and a new session header (in case the user changed password)
            if($_POST['password'] == $_SESSION['auth_head']['auth_head_password'] || $_POST['password'] == md5($_SESSION['auth_head']['auth_head_password'])){
                // we leave the auth head session as is
            }else{
                $user_login = array(
                        'auth_head_user_name'=>str_replace(' ','',$_SESSION['user_data']['user_name']),
                        'auth_head_password'=>str_replace(' ','',$_POST['password']),
                        'auth_head_company_id'=>COMPANY_ID
                );
                $_SESSION['auth_head'] = $user_login;
            }
            header("location: ".CURRENT_PAGE."?do=success");
        }
    }
}

require_once(WEB_ROOT.'/incl/top.php');

?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">

    <form action="<?php echo CURRENT_PAGE."?do=save"; ?>" method="post">
    <h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_profile', DEFAULT_LANG); ?></h2>
    <?php

        if($err_message != ''){
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
        }
        if($_GET['do'] == 'success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_profile_save_success', DEFAULT_LANG)."</div>";
        }
    ?>
    <div class="tabbable"> <!-- Only required for left/right tabs -->
    <ul class="nav nav-tabs">
    <li class="active"><a href="#profile_personal" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_personal', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_professional" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_professional', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_account" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_account', DEFAULT_LANG); ?></a></li>
    </ul>
    <div class="tab-content">
    <div class="tab-pane active" id="profile_personal">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['personal'], DEFAULT_LANG, $_SESSION['user_data'], $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_professional">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['professional'], DEFAULT_LANG, $_SESSION['user_data'], $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_account">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['account'], DEFAULT_LANG, $_SESSION['user_data'], $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    </div>
    </div>
    <button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_save', DEFAULT_LANG); ?></button>
    </form>

<?php

require_once(WEB_ROOT.'/incl/bottom.php');

?>
