<?php
/*
*
* Copyright (c) 2014 AM Data Soft
* Distributed under the GNU GPL v3.
* License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
*
*/

/*
*
* Purpose:         Allows editing, viewing and addition of users. Form field 
*                  components are driven from the lib/form_fields.php file, 
*                  $arr_user_data_format array (same as the profile module). 
*                  It is mandatory that you pre-define form fields in 
*                  $arr_user_data_format and add necessary labels in all used 
*                  language files before applying changes to this module. 
*                  After each change or addition to the users list, the 
*                  users_list and users_list_create_dt sessions must be refreshed. 
*                  Also, any changes to the existing logged in user should be 
*                  performed from the profile page rather than from this module.
* 
* Developer:       AM Data Soft
* Version:         1.0
* Version date:    2014-04-10
*
*/

session_start();

require_once('settings.php');

date_default_timezone_set(DEFAULT_TIMEZONE);
define('SID', session_id());
define('CURRENT_PAGE', $_SERVER['SCRIPT_NAME']);
define('CURRENT_SCRIPT', $_SERVER['SCRIPT_FILENAME']);
define('CURRENT_URL',$_SERVER['REQUEST_URI']);

require_once(WEB_ROOT.'/lib/rest_client.php');
require_once(WEB_ROOT.'/incl/security.php');

if($_SESSION['user_data']['access_level'] != 'ADMIN' && $_SESSION['user_data']['access_level'] != 'MANAGER'){
    header('location: logout.php');
}

if (!isset($_SESSION['users_list'])){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $users_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/user',json_encode($comp_id,true));
    $arr_users_list = json_decode($users_list_return, true);
    if(count($arr_users_list) > 0){
        $_SESSION['users_list'] = $arr_users_list;
        $_SESSION['users_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }
}

// form actions

// show users list as json for search
if($_GET['do'] == 'json'){
    $arr_json = [];
    $i = 0;
    foreach ($_SESSION['users_list']['item_list']  as $usr_data){
        $arr_user = $utilities_library->mk_array($usr_data['key'],$usr_data['property_list']);
        $arr_u = ['id' => $usr_data['key'], 'name'=>"".$arr_user['first_name']." ".$arr_user['last_name']." [".$arr_user['user_name']."] <".$arr_user['personal_email'].">"];
        $arr_json[$i] = $arr_u;
        $i = $i + 1;
    }
    header('Cache-Control: no-cache, must-revalidate');
    header('Content-type: application/json');
    print json_encode($arr_json,true);
    exit;
}

if($_GET['do'] == 'json_download' || $_GET['do'] == 'xml_download'){
    $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $users_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/user',json_encode($comp_id,true));
    $arr_users_list = json_decode($users_list_return, true);
    if(count($arr_users_list) > 0){
        $_SESSION['users_list'] = $arr_users_list;
        $_SESSION['users_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
    }else{
        $err_msg = "";
    }
    $arr_json = [];
    foreach ($_SESSION['users_list']['item_list']  as $usr_data){
        $arr_usr = $utilities_library->mk_array($usr_data['key'],$usr_data['property_list']);
        $arr_json[$usr_data['key']] = $arr_usr;
    }
    header('Cache-Control: no-cache, must-revalidate');

    if($_GET['do'] == 'json_download'){
        header("Content-Disposition: attachment; filename=users.json");
        header('Content-type: application/json');
        print json_encode($arr_json,true);
        exit;
    }else if($_GET['do'] == 'xml_download'){
        $xml1 = xmlrpc_encode($arr_json);
        header("Content-Disposition: attachment; filename=users.xml");
        header('Content-type: application/json');
        echo $xml1;
        exit;
    }
}


// add a new user
if($_GET['do'] == 'add'){
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    $err_message = "";
    // form field validation
    $form_validation = $utilities_library->form_fields_validation($arr_user_data_format,$_POST);
    
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        // avoid EOL while scanning string literal errors
        foreach ($arr_user_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }
        // make array with all required components
        // note the user key is blank ('')
        $post_usr_data = $utilities_library->mk_json_props_array('',$_POST,$_POST);

        // submit to app server
        $user_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/user',json_encode($post_usr_data,true));
        $arr_user_return = json_decode($user_return,true);
        // check for final errors
        if ((str_replace(' ','',$arr_user_return['message']) != '' && $arr_user_return['status'] > 300 && $arr_usr_return['status'] < 600) || (str_replace(' ','',$arr_co_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
            $err_message = $arr_user_return['message'];
        }else{
            // no errors; we re-generate the users list session and 
            // redirect to nice success page
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $users_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/user',json_encode($comp_id,true));
            $arr_users_list = json_decode($users_list_return, true);
            if(count($arr_users_list) > 0){
                $_SESSION['users_list'] = $arr_users_list;
                $_SESSION['users_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }
            header("location: ".CURRENT_PAGE."?do=adduser_success");
        }
    }
}

// update existing user
if($_GET['do'] == 'save'){
    $err_message = "";
    $is_user = false;
    $toedit_user = [];
    $user_key = null;
    $user_co = null;
    $user_level = null;
    foreach ($_SESSION['users_list']['item_list'] as $usr_data){
        if ($usr_data['key'] == $_GET['uid']){
            $is_user = true;
            $user_key = $usr_data['key'];
            $toedit_user = $utilities_library->mk_array($usr_data['key'],$usr_data['property_list']);
        }
    }
    if($toedit_user['access_level'] == 'USER' || $toedit_user['access_level'] == 'MANAGER' ){
        //nothing to do
    }else{
        $is_user = false;
    }
    if($toedit_user['company_id'] == $_SESSION['auth_head']['auth_head_company_id'] ){
        //nothing to do
    }else{
        $is_user = false;
    }

    if ($is_user == false){
        $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
    }
    
    $rest_client = new rest_client($_SESSION['auth_head'],'');
    // form field validation
    $form_validation = $utilities_library->form_fields_validation($arr_user_data_format,$_POST);
    
    if(count($form_validation) > 0){
        foreach ($form_validation as $err_detail) {
            $err_message .= "".$err_detail['field_label'].": ".$err_detail['field_error']."<br />";
        }
    }else{
        // avoid EOL while scanning string literal errors
        foreach ($arr_user_data_format as &$form_object){
            foreach($form_object as &$form_data){
                $field_type = $form_data['field_type'];
                if(isset($field_type) && $field_type == 'textarea'){
                    $field_name = $form_data['field_name'];
                    $_POST[$field_name] = base64_encode($_POST[$field_name]);
                }
            }
        }
        // make array with all required components
        $post_usr_data = $utilities_library->mk_json_props_array($user_key,$toedit_user,$_POST);

        // submit to app server
        $user_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/user',json_encode($post_usr_data,true));
        $arr_usr_return = json_decode($user_return, true);
        // check for final errors
        if ((str_replace(' ','',$arr_usr_return['message']) != '' && $arr_usr_return['status'] > 300 && $arr_usr_return['status'] < 600) || (str_replace(' ','',$arr_co_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
            $err_message = $user_return['message'];
        }else{
            // re-create the user list session
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $users_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/user',json_encode($comp_id,true));
            $arr_users_list = json_decode($users_list_return, true);
            if(count($arr_users_list) > 0){
                $_SESSION['users_list'] = $arr_users_list;
                $_SESSION['users_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }
            header("location: ".CURRENT_PAGE."?do=save_success&pg=".$_GET['pg']."&su_id=".$_GET['uid']."");
        }
    }

}

if($_GET['do'] == 'edit_user'){
    $pgnum = 0;
    try{
        $pgnum = $_GET['pg'];
    } catch (Exception $e) {
        $pgnum = 0;
    }
    $uid = null;
    try{
        $uid = $_GET['uid'];
    } catch (Exception $e) {
        $uid = null;
    }
    if($uid != null){
        header("location: ".CURRENT_PAGE."?uid=".$_GET['uid']."&pg=".$pgnum."&do=modify_user");
    }
}

// deactivate/activate existing user
if($_GET['do'] == 'deactivate' || $_GET['do'] == 'activate'){
    // let's check a few things; 
    // is the user de-activating itself?
    $err_message = "";
    if($_GET['uid'] == $_SESSION['user_data']['key']){
        $err_message = ['field_name' => null, 'field_label' => null, 'field_error' => $formatting_library->make_lang_label($arr_labels, 'lbl_err_cannot_deactivate_self', DEFAULT_LANG), 'field_value' => null];
    }else{
        $rest_client = new rest_client($_SESSION['auth_head'],'');
        // get array of user values
        // set active_yn
        $arr_new_user_data = [];
        foreach ($_SESSION['users_list']['item_list'] as $usr_arr) {
            if($usr_arr['key'] == $_GET['uid']){
                foreach ($usr_arr['property_list'] as $usr_prop){
                    // fix for unconverted data remains: .000000 error
                    // when ms are added in a date/time string
                    if($usr_prop['prop_name'] == 'created_on'){
                        $arr_new_user_data = ['created_on' => str_replace('.000000','',$usr_prop['prop_value'])]+$arr_new_user_data;
                    }else if($usr_prop['prop_name'] == 'modified_on'){
                        $arr_new_user_data = ['modified_on' => str_replace('.000000','',$usr_prop['prop_value'])]+$arr_new_user_data;
                    }else{
                        $arr_new_user_data = [$usr_prop['prop_name'] => $usr_prop['prop_value']]+$arr_new_user_data;
                    }
                }
            }
        }
        if($_GET['do'] == 'activate'){
            $arr_new_user_data = ['active_yn' => 'True']+$arr_new_user_data;
        }else{
            $arr_new_user_data = ['active_yn' => 'False']+$arr_new_user_data;
        }

        // send back to server
        $post_usr_data = $utilities_library->mk_json_props_array($_GET['uid'],$arr_new_user_data,$arr_new_user_data);

        // submit to app server
        $user_return = $rest_client->put(WEB_SERVICE_ADDRESS.'/user',json_encode($post_usr_data,true));
        $arr_usr_return = json_decode($user_return,true);
        // check for final errors
        if ((str_replace(' ','',$arr_usr_return['message']) != '' && $arr_usr_return['status'] > 300 && $arr_usr_return['status'] < 600) || (str_replace(' ','',$arr_co_return['message']) != '' && $arr_co_return['status'] > 300 && $arr_co_return['status'] < 600)) {
            $err_message = $arr_usr_return['message'];
        }else{
            // no errors; we re-generate the users list session and
            // redirect to nice success page
            $comp_id = ['company_id' => $_SESSION['auth_head']['auth_head_company_id']];
            $rest_client = new rest_client($_SESSION['auth_head'],'');
            $users_list_return = $rest_client->listobj(WEB_SERVICE_ADDRESS.'/user',json_encode($comp_id,true));
            $arr_users_list = json_decode($users_list_return, true);
            if(count($arr_users_list) > 0){
                $_SESSION['users_list'] = $arr_users_list;
                $_SESSION['users_list_create_dt'] = gmdate("Y-m-d H:i:s", time());
            }
            $pgnum = 0;
            try{
                $pgnum = $_GET['pg'];
            } catch (Exception $e) {
                $pgnum = 0;
            }
            
            if($_GET['do'] == 'activate'){
                header("location: ".CURRENT_PAGE."?do=activate_success&pg=".$pgnum."&su_id=".$_GET['uid']."");
            }else{
                header("location: ".CURRENT_PAGE."?do=deactivate_success&pg=".$pgnum."&su_id=".$_GET['uid']."");
            }
        }
    }
}

require_once(WEB_ROOT.'/incl/top.php');

?>

<body>

<?php
require_once(WEB_ROOT.'/incl/head.php');
?>

    <div class="container">



<h2 class="form-signin-heading"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_users', DEFAULT_LANG); ?></h2>

<div class="row">
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#new_user" role="button" class="btn btn-primary" data-toggle="modal"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_user', DEFAULT_LANG); ?></a>
    <div class="btn-group">
        <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
            <?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_download', DEFAULT_LANG); ?> <span class="caret"></span>
        </button>
        <ul class="dropdown-menu" role="menu">
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=xml_download">XML</a></li>
            <li><a href="<?php echo CURRENT_PAGE; ?>?do=json_download">JSON</a></li>
        </ul>
    </div>
</div>
<br />

<!-- begin search section -->

<form class="form-horizontal" role="form" name="usr_srch_form" id="usr_srch_form" action="<?php echo CURRENT_PAGE; ?>" method="get">
<div class="form-group">
<label for="u_srch" class="col-lg-2 control-label"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></label>
<div class="col-lg-6">
    <input
        type="text" 
        id="user-input" 
        class="form-control typeahead"
        placeholder="<?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search_username_field', DEFAULT_LANG); ?>"
        autocomplete="off"
        data-provide="typeahead"
    />
    </div>
    
<input type="hidden" name="su_id" id="su_id" value="" /><button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_search', DEFAULT_LANG); ?></button>
</div>
</form>
    <script src="js/jquery-1.9.1.min.js"></script>
    <script src="js/bootstrap.min2.js"></script>
    <script src="js/underscore-min.js"></script>

    <script type="text/javascript">

    $(function(){
        var usrObjs = {};
        var usrNames = [];
        $(".typeahead").typeahead({
            source: function ( query, process ) {
                $.ajax({
                    url: '<?php echo CURRENT_PAGE; ?>?do=json'
                    ,cache: false
                    ,success: function(data){
                        usrObjs = {};
                        usrNames = [];
                        _.each( data, function(item, ix, list){
                            usrNames.push( item.name );
                            usrObjs[ item.name ] = item.id;
                        });
                        process( usrNames );
                    }
                });
            }
            , items: 15
            , updater: function ( selectedName ) {
                $( "#su_id" ).val( usrObjs[ selectedName ] );
                return selectedName;
            }
        });
    });

    </script>

<br />
<!-- end search section -->

    <?php
        if($err_message != ''){
            print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
        }
        if($_GET['do'] == 'adduser_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_user_add_success', DEFAULT_LANG)."</div>";
        }
        if($_GET['do'] == 'deactivate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_user_deactivate_success', DEFAULT_LANG)."</div>";
        }
        if($_GET['do'] == 'activate_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_user_activate_success', DEFAULT_LANG)."</div>";
        }
        if($_GET['do'] == 'save_success'){
            print "<div class=\"alert alert-success\">".$formatting_library->make_lang_label($arr_labels, 'lbl_user_save_success', DEFAULT_LANG)."</div>";
        }
    ?>


<?php 
if($_GET['do'] != 'modify_user'){
?>

<table class="table table-striped">
<tr>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_username', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_full_name', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_access_level', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_last_modified', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_status', DEFAULT_LANG); ?></th>
    <th><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_action', DEFAULT_LANG); ?></th>
</tr>

<?php 
    $pgnum = 0;
    try{
        $pgnum = $_GET['pg'];
    } catch (Exception $e) {
        $pgnum = 0;
    }
    $start_rec = $pgnum * MAX_RECS_PER_PAGE;
    $end_rec = $start_rec + MAX_RECS_PER_PAGE;
    $arr_users_list = $_SESSION['users_list']['item_list'];
    $no_paging = false;
    if($_GET['su_id'] != ''){
        // user search; display only that record
        $arr_user_search = [];
        foreach ($_SESSION['users_list']['item_list'] as $u_list){
            if($u_list['key'] == $_GET['su_id']){
                $arr_user_search[0] = $u_list;
            }
        }
        if(count($arr_user_search) > 0){
            $arr_users_list = $arr_user_search;
            $no_paging = true;
        }else{
            $arr_users_list = $_SESSION['users_list']['item_list'];
        }
    }
    if(count($_SESSION['users_list']['item_list']) <= MAX_RECS_PER_PAGE){
        $no_paging = true;
    }else if($start_rec > count($_SESSION['users_list']['item_list'])){
        $start_rec = 0;
        $end_rec = $start_rec + MAX_RECS_PER_PAGE;
        $pg_num = 0;
    }

    print $utilities_library->make_users_table($arr_users_list,$_SESSION['user_data'], DEFAULT_LANG, CURRENT_PAGE, $start_rec, $end_rec, $arr_labels, $pgnum);

    print "</table>";

    if($no_paging == false  && $_GET['do'] != 'edit_user'){
        print $utilities_library->make_pagination(count($arr_users_list),$pgnum,CURRENT_PAGE,$arr_labels);
    }else if($_GET['su_id'] != '' || $_GET['do'] == 'edit_user'){
        print "<ul class=\"pagination pagination-sm\">";
        print "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
        print "</ul>";
    }

}else{
    // edit user form
    // validate user ID is correct
    $is_user = false;
    $toedit_user = [];
    foreach ($_SESSION['users_list']['item_list'] as $usr_data){
        if ($usr_data['key'] == $_GET['uid']){
            $is_user = true;
            $toedit_user = $utilities_library->mk_array($usr_data['key'],$usr_data['property_list']);
        }
    }
    if ($is_user == false){
        print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$formatting_library->make_lang_label($arr_labels, 'lbl_err_no_such_user', DEFAULT_LANG)."</div>";
    }else{
    
?>
    <!-- <div class="tabbable col-lg-8">  Only required for left/right tabs -->
    <form action="<?php echo CURRENT_PAGE."?do=save&pg=".$_GET['pg']."&uid=".$_GET['uid'].""; ?>" method="post">
    
    <ul class="nav nav-tabs">
    <li class="active"><a href="#eprofile_personal" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_personal', DEFAULT_LANG); ?></a></li>
    <li><a href="#eprofile_professional" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_professional', DEFAULT_LANG); ?></a></li>
    <li><a href="#eprofile_account" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_account', DEFAULT_LANG); ?></a></li>
    </ul>
    <div class="tab-content">
    <br />
    <div class="tab-pane active" id="eprofile_personal">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['personal'], DEFAULT_LANG, $toedit_user, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="eprofile_professional">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['professional'], DEFAULT_LANG, $toedit_user, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="eprofile_account">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['account'], DEFAULT_LANG, $toedit_user, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    </div>

    <button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels,'lbl_btn_save',DEFAULT_LANG); ?></button>
    </form>
    
<?php 
    }
    $html_ret .= "<ul class=\"pagination pagination-sm\">";
    $html_ret .= "<li><a href=\"".CURRENT_PAGE."?pg=".$_GET['pg']."\">".$formatting_library->make_lang_label($arr_labels,'lbl_previous',DEFAULT_LANG)."</a></li>";
    $html_ret .= "</ul>";
    print $html_ret;
}    
?>
<!--    </div> -->




<form action="<?php echo CURRENT_PAGE; ?>?do=add" method="post">

<div class="modal fade" id="new_user" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
<div class="modal-dialog">
<div class="modal-content">

<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true"></button>
<h3 id="myModalLabel"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_new_user', DEFAULT_LANG); ?></h3>
</div>
<div class="modal-body">
    
    <?php 
    if($err_message != ''){
        print "<div class=\"alert alert-danger\"><b>".$formatting_library->make_lang_label($arr_labels, 'lbl_err_head', DEFAULT_LANG).":</b><br />".$err_message."</div>";
    }
    ?>
    
    <div class="tabbable"> <!-- Only required for left/right tabs -->
    <ul class="nav nav-tabs">
    <li class="active"><a href="#profile_personal" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_personal', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_professional" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_professional', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_account" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_account', DEFAULT_LANG); ?></a></li>
    </ul>
    <div class="tab-content">
    <br />
    <div class="tab-pane active" id="profile_personal">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['personal'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_professional">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['professional'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_account">
    <?php

    // a few items that need to be modified for the form to display properly
    // first, the username must not be read-only.
    $acct_array = $arr_user_data_format['account'];
    $username_rw = ['user_name' => [
                'field_label' => $arr_user_data_format['account']['user_name']['field_label'],
                'field_name' => $arr_user_data_format['account']['user_name']['field_name'],
                'field_default_val' => $arr_user_data_format['account']['user_name']['field_default_val'],
                'field_readonly' => false,
                'field_length' => $arr_user_data_format['account']['user_name']['field_length'],
                'field_type' => $arr_user_data_format['account']['user_name']['field_type'],
                'field_validate' => $arr_user_data_format['account']['user_name']['field_validate']
            ]
    ];
    $acct_array = array_replace($acct_array,$username_rw);
    /*
    // second, we add a secondary password validation field
    // disabled for now as the secondary field is added to the end of the form
    $npasswd = ['password' => [
                'field_label' => $arr_user_data_format['account']['password']['field_label'],
                'field_name' => $arr_user_data_format['account']['password']['field_name'],
                'field_default_val' => $arr_user_data_format['account']['password']['field_default_val'],
                'field_readonly' => $arr_user_data_format['account']['password']['field_readonly'],
                'field_length' => $arr_user_data_format['account']['password']['field_length'],
                'field_type' => $arr_user_data_format['account']['password']['field_type'],
                'field_validate' => $arr_user_data_format['account']['password']['field_validate']
            ],
            'password2' => [
                'field_label' => $arr_user_data_format['account']['password']['field_label'],
                'field_name' => $arr_user_data_format['account']['password']['field_name'],
                'field_default_val' => $arr_user_data_format['account']['password']['field_default_val'],
                'field_readonly' => $arr_user_data_format['account']['password']['field_readonly'],
                'field_length' => $arr_user_data_format['account']['password']['field_length'],
                'field_type' => $arr_user_data_format['account']['password']['field_type'],
                'field_validate' => $arr_user_data_format['account']['password']['field_validate']
            ]
    ];
    $acct_array = array_replace($acct_array,$npasswd);
    */

    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $acct_array, DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    </div> <!-- end tab content -->
    </div> <!-- end tabbable -->
    </div> <!-- end modal body -->

<div class="modal-footer">
<button class="btn btn-danger" data-dismiss="modal" aria-hidden="true"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_cancel', DEFAULT_LANG); ?></button>
<button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_add_user', DEFAULT_LANG); ?></button>
</div>
</div>
</div>
</div>
</form>



<form class="form-horizontal" role="form" action=".<?php echo CURRENT_PAGE; ?>?do=edit" method="post">

<div id="edit_user" class="modal hide fade" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
<h3 id="myModalLabel"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_pghead_edit_user', DEFAULT_LANG); ?></h3>
</div>
<div class="modal-body">

    <div class="tabbable"> <!-- Only required for left/right tabs -->
    <ul class="nav nav-tabs">
    <li class="active"><a href="#profile_personal" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_personal', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_professional" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_professional', DEFAULT_LANG); ?></a></li>
    <li><a href="#profile_account" data-toggle="tab"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_tab_account', DEFAULT_LANG); ?></a></li>
    </ul>
    <div class="tab-content">
    <br />
    <div class="tab-pane active" id="profile_personal">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['personal'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_professional">
    <?php
    print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['professional'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div>
    <div class="tab-pane" id="profile_account">
    <?php
        print "<div class=\"span4\">";
    print $formatting_library->make_form($arr_labels, $arr_user_data_format['account'], DEFAULT_LANG, null, $_POST, $form_validation);
    print "</div>";
    ?>
    </div> <!-- end tab content -->
    </div> <!-- end tabbable -->
    </div> <!-- end modal body -->

<div class="modal-footer">
<button class="btn btn-danger" data-dismiss="modal" aria-hidden="true"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_cancel', DEFAULT_LANG); ?></button>
<button class="btn btn-success" type="submit"><?php echo $formatting_library->make_lang_label($arr_labels, 'lbl_btn_save', DEFAULT_LANG); ?></button>
</div>

</div>
</div>
</form>

<?php

$no_js = true;
require_once(WEB_ROOT.'/incl/bottom.php');

?>
